//////////////////////////////////////////////////////////////////
//                                                             
// Copyright (C) 2009 Pulse Logic                        
//                    info@pulselogic.com.pl                   
//                                                             
// This source file may be used and distributed without        
// restriction provided that this copyright statement is not   
// removed from the file and that any derivative work contains 
// the original copyright notice and the associated disclaimer.
//                                                             
//     THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY     
// EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED   
// TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS   
// FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL THE AUTHOR      
// OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,         
// INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES    
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE   
// GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR        
// BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF  
// LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR TORT  
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  
// OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE         
// POSSIBILITY OF SUCH DAMAGE.                                 
//                                                             
//////////////////////////////////////////////////////////////////
//
// Title       : Float32Div
// Design      : Float32 RTL Library
// Company     : Pulse Logic
//
//////////////////////////////////////////////////////////////////
//
// File        : Float32Div.v
// Tool        : Xilinx WebPack
//
//////////////////////////////////////////////////////////////////
//
// Description : IEEE 754 single precision synchronous floating point divider.
//				 Obfuscated code. 
//////////////////////////////////////////////////////////////////

module Float32Div(CLK, nRST, leftArg, rightArg, loadArgs, status, busy, quotient);
input CLK;              //Global clock. Rising edge active.  
input nRST;             //Global reset. Active low.  
input [31:0] leftArg;   //Left argument. Bit 31 - sign, Bits 30:23 exponent, Bits 22:0 mantissa.
input [31:0] rightArg;  //Right argument. Bit 31 - sign, Bits 30:23 exponent, Bits 22:0 mantissa.
input loadArgs;         //Arguments load strobe. Active high.
output [2:0] status;    //Status output. Bit 2 - Not a Number, Bit 1 - Infinity, Bit 0 - Denormal.
output busy;            //busy - high means performing calculations, low means result ready.
output [31:0] quotient; //Result. Valid if busy bit is low. Status bits 2:0 denote exceptions. 

wire[31:0]quotient;wire[2:0]status;wire busy;wire IOOOO1,I0OOO1;reg IIOOO1;wire IlOOO1,I1OOO1;reg IOO0O1;wire I0O0O1,IIO0O1;reg IlO0O1;wire I1O0O1,IOOIO1;reg [2:0]I0OIO1;wire[2:0]IIOIO1;wire IlOIO1;reg I1OIO1
;wire IOOlO1,I0OlO1;reg [2:0]IIOlO1;wire[2:0]IlOlO1;wire I1OlO1;reg IOO1O1;wire I0O1O1,IIO1O1;reg [2:0]IlO1O1;wire[2:0]I1O1O1;wire IOOO01;reg I0OO01;wire IIOO01,IlOO01;reg [2:0]I1OO01;wire[2:0]IOO001;wire I0O001
;reg IIO001;wire IlO001,I1O001;reg [2:0]IOOI01;reg [2:0]I0OI01;wire IIOI01;reg IlOI01;wire I1OI01,IOOl01;reg [2:0]I0Ol01;wire[2:0]IIOl01;wire IlOl01;reg I1Ol01;wire IOO101,I0O101;reg [2:0]IIO101;wire[2:0]IlO101
;wire I1O101;reg IOOOI1;wire I0OOI1,IIOOI1;reg [2:0]IlOOI1;wire[2:0]I1OOI1;wire IOO0I1;reg I0O0I1;wire IIO0I1,IlO0I1;reg [2:0]I1O0I1;wire[2:0]IOOII1;wire I0OII1;reg IIOII1;wire IlOII1,I1OII1;reg [2:0]IOOlI1
;wire[2:0]I0OlI1;wire IIOlI1;reg IlOlI1;wire I1OlI1,IOO1I1;reg I0O1I1;wire IIO1I1,IlO1I1;reg [2:0]I1O1I1;reg [2:0]IOOOl1;wire I0OOl1;reg IIOOl1;wire IlOOl1,I1OOl1;reg [9:0]IOO0l1;reg [9:0]I0O0l1;wire IIO0l1
;reg [53:0]IlO0l1;wire[53:0]I1O0l1;wire IOOIl1;reg [4:0]I0OIl1;wire[4:0]IIOIl1;wire IlOIl1;reg I1OIl1;wire IOOll1,I0Oll1;reg [4:0]IIOll1;wire[4:0]IlOll1;wire I1Oll1;reg [31:0]IOO1l1;wire[31:0]I0O1l1;wire IIO1l1
;reg [7:0]IlO1l1;wire[7:0]I1O1l1;wire IOOO11;reg I0OO11;wire IIOO11,IlOO11;reg [23:0]I1OO11;wire[23:0]IOO011;wire I0O011;reg [53:0]IIO011;wire[53:0]IlO011;wire I1O011;reg IOOI11;wire I0OI11,IIOI11;reg [4:0
]IlOI11;wire[4:0]I1OI11;wire IOOl11;reg [28:0]I0Ol11;wire[28:0]IIOl11;wire IlOl11;reg [27:0]I1Ol11;wire[27:0]IOO111;wire I0O111;reg [31:0]IIO111;wire[31:0]IlO111;wire I1O111;reg [7:0]IO0OO1;wire[7:0]I00OO1
;wire II0OO1;reg Il0OO1;wire I10OO1,IO00O1;reg [23:0]I000O1;wire[23:0]II00O1;wire Il00O1;reg I100O1;wire IO0IO1,I00IO1;reg II0IO1;wire Il0IO1,I10IO1;reg [8:0]IO0lO1;wire[8:0]I00lO1;wire II0lO1;reg [4:0]Il0lO1
;wire[4:0]I10lO1;wire IO01O1;reg [4:0]I001O1;wire[4:0]II01O1;wire Il01O1;reg I101O1;wire IO0O01,I00O01;reg II0O01;wire Il0O01,I10O01;reg [27:0]IO0001;reg [27:0]I00001;wire II0001;wire Il0001,I10001,IO0I01,I00I01
,II0I01,Il0I01,I10I01,IO0l01,I00l01,II0l01,Il0l01,I10l01,IO0101,I00101,II0101,Il0101,I10101,IO0OI1,I00OI1,II0OI1,Il0OI1,I10OI1,IO00I1,I000I1,II00I1,Il00I1,I100I1,IO0II1,I00II1,II0II1,Il0II1,I10II1,IO0lI1
,I00lI1,II0lI1,Il0lI1,I10lI1,IO01I1,I001I1,II01I1,Il01I1,I101I1,IO0Ol1,I00Ol1,II0Ol1,Il0Ol1,I10Ol1,IO00l1,I000l1,II00l1,Il00l1,I100l1,IO0Il1,I00Il1,II0Il1,Il0Il1,I10Il1,IO0ll1,I00ll1,II0ll1,Il0ll1,I10ll1
,IO01l1,I001l1,II01l1,Il01l1,I101l1,IO0O11,I00O11,II0O11,Il0O11,I10O11,IO0011,I00011,II0011,Il0011,I10011,IO0I11,I00I11,II0I11,Il0I11,I10I11,IO0l11,I00l11,II0l11,Il0l11,I10l11,IO0111,I00111,II0111,Il0111
,I10111,IOIOO1,I0IOO1,IIIOO1,IlIOO1,I1IOO1,IOI0O1,I0I0O1,III0O1,IlI0O1,I1I0O1,IOIIO1,I0IIO1,IIIIO1,IlIIO1,I1IIO1,IOIlO1,I0IlO1,IIIlO1,IlIlO1,I1IlO1,IOI1O1,I0I1O1,III1O1,IlI1O1,I1I1O1,IOIO01,I0IO01,IIIO01
,IlIO01,I1IO01,IOI001,I0I001,III001,IlI001,I1I001,IOII01,I0II01,IIII01,IlII01,I1II01,IOIl01,I0Il01,IIIl01,IlIl01,I1Il01,IOI101,I0I101,III101,IlI101,I1I101,IOIOI1,I0IOI1,IIIOI1,IlIOI1,I1IOI1,IOI0I1,I0I0I1
,III0I1,IlI0I1,I1I0I1,IOIII1,I0III1,IIIII1,IlIII1,I1III1,IOIlI1,I0IlI1,IIIlI1,IlIlI1,I1IlI1,IOI1I1,I0I1I1,III1I1,IlI1I1,I1I1I1,IOIOl1,I0IOl1,IIIOl1,IlIOl1,I1IOl1,IOI0l1,I0I0l1,III0l1,IlI0l1,I1I0l1,IOIIl1
,I0IIl1,IIIIl1,IlIIl1,I1IIl1;reg [53:0]IOIll1;wire[53:0]I0Ill1;wire[27:0]IIIll1,IlIll1,I1Ill1,IOI1l1,I0I1l1;wire[23:0]III1l1,IlI1l1,I1I1l1,IOIO11;wire[9:0]I0IO11,IIIO11,IlIO11,I1IO11;wire[4:0]IOI011,I0I011
;wire III011,IlI011,I1I011,IOII11,I0II11,IIII11,IlII11,I1II11,IOIl11,I0Il11,IIIl11,IlIl11,I1Il11;reg [28:0]IOI111;wire[53:0]I0I111,III111,IlI111,I1I111,IOlOO1,I0lOO1,IIlOO1,IllOO1,I1lOO1,IOl0O1,I0l0O1,
IIl0O1,Ill0O1,I1l0O1,IOlIO1,I0lIO1,IIlIO1,IllIO1,I1lIO1,IOllO1,I0llO1,IIllO1,IlllO1,I1llO1,IOl1O1,I0l1O1,IIl1O1,Ill1O1;wire[31:0]I1l1O1,IOlO01,I0lO01,IIlO01,IllO01,I1lO01,IOl001,I0l001,IIl001,Ill001,I1l001
,IOlI01,I0lI01,IIlI01,IllI01,I1lI01,IOll01,I0ll01,IIll01,Illl01,I1ll01,IOl101,I0l101,IIl101,Ill101,I1l101,IOlOI1,I0lOI1,IIlOI1,IllOI1,I1lOI1,IOl0I1,I0l0I1,IIl0I1,Ill0I1,I1l0I1,IOlII1,I0lII1,IIlII1,IllII1
,I1lII1;wire[28:0]IOllI1,I0llI1,IIllI1,IlllI1;wire[27:0]I1llI1,IOl1I1,I0l1I1,IIl1I1,Ill1I1;wire[26:0]I1l1I1;wire[9:0]IOlOl1,I0lOl1,IIlOl1;wire[4:0]IllOl1,I1lOl1;wire IOl0l1,I0l0l1,IIl0l1,Ill0l1,I1l0l1,
IOlIl1,I0lIl1,IIlIl1,IllIl1,I1lIl1,IOlll1,I0lll1,IIlll1,Illll1,I1lll1,IOl1l1,I0l1l1,IIl1l1,Ill1l1,I1l1l1,IOlO11,I0lO11,IIlO11,IllO11,I1lO11,IOl011,I0l011,IIl011,Ill011,I1l011,IOlI11,I0lI11,IIlI11,IllI11
,I1lI11,IOll11,I0ll11,IIll11,Illl11,I1ll11,IOl111,I0l111,IIl111,Ill111,I1l111,IO1OO1,I01OO1,II1OO1,Il1OO1,I11OO1,IO10O1,I010O1,II10O1,Il10O1,I110O1,IO1IO1,I01IO1,II1IO1,Il1IO1,I11IO1,IO1lO1,I01lO1,II1lO1
,Il1lO1,I11lO1,IO11O1,I011O1,II11O1,Il11O1,I111O1,IO1O01,I01O01,II1O01,Il1O01,I11O01,IO1001,I01001,II1001,Il1001,I11001,IO1I01,I01I01,II1I01,Il1I01,I11I01,IO1l01,I01l01,II1l01,Il1l01,I11l01,IO1101,I01101
,II1101,Il1101,I11101,IO1OI1,I01OI1,II1OI1,Il1OI1;assign II0111=1'd1;assign IlIIl1=loadArgs;assign status={IOOI11,I1OIl1,IlO0O1};assign busy=IOO0O1;assign quotient={I101O1,IOO0l1[7:0],IO0001[25:3]};assign
Il0111=1'd1;assign I1IIl1=1'd1;assign IO0II1=I01OO1&& I1O1I1== 3'd2&& IIOll1!= 5'd0;assign I0IO01=IO0II1;assign I00II1=II1OO1&& I1O1I1== 3'd3&& IIOll1!= 5'd0;assign IIIO01=I00II1;assign II0II1=Il0l01;
assign IlIO01=Il0l01;assign Il0II1=I10l01;assign I1IO01=I10l01;assign I10lI1=I01IO1&& I1O1I1== 3'd3&& IIOll1== 5'd0;assign IOII01=I10lI1;assign IO0I01=IO0lO1[0];assign I0IOO1=IO0I01;assign IO0111=Il10O1
&& IO1IO1&& (I1O1I1== 3'd5|| I1O1I1== 3'd1&& !IIOOl1)&& !I0O1I1&& IO0lO1[3];assign I0IIl1=IO0111;assign II01I1=I110O1&& I0O1I1;assign IlII01=II01I1;assign I000I1=Il0I01;assign III1O1=Il0I01;assign I100I1
=I00l01;assign IOIO01=I00l01;assign II0Ol1=IO1OO1&& Il1OO1&& IOOI01== 3'd3;assign IlIl01=II0Ol1;assign IO0lI1=I00101;assign I0I001=I00101;assign I00I01=IO0lO1[1];assign IIIOO1=I00I01;assign Il0I01=I11IO1
&& II1IO1&& Il1IO1&& I1O1I1== 3'd1&& (II01I1|| IIOOl1);assign I1IOO1=Il0I01;assign I00l01=I1O0I1== 3'd1&& (Il0I01|| IIOII1);assign III0O1=I00l01;assign Il00I1=IO0l01;assign I1I1O1=IO0l01;assign IO0l01
=IlOOI1== 3'd1&& (Il0I01|| I0O0I1);assign I0I0O1=IO0l01;assign II00I1=I10I01;assign IlI1O1=I10I01;assign I10I01=IOOlI1== 3'd1&& (Il0I01|| IlOlI1);assign IOI0O1=I10I01;assign II0l01=IIIO01|| I0IO01;assign
IlI0O1=II0l01;assign II0lI1=Il0101;assign IlI001=Il0101;assign Il0101=I1OO01== 3'd1&& (II0l01|| IIO001);assign I1IIO1=Il0101;assign I00lI1=II0101;assign III001=II0101;assign II0101=IlO1O1== 3'd1&& (II0l01
|| I0OO01);assign IlIIO1=II0101;assign Il0l01=IOOI01== 3'd1&& (II0l01|| IlOI01)&& IOllI1[28];assign I1I0O1=Il0l01;assign I10l01=Il1OO1&& IO1OO1&& II10O1;assign IOIIO1=I10l01;assign I00101=I0OIO1== 3'd1
&& (I10l01|| I1OIO1);assign IIIIO1=I00101;assign I10II1=IO0101;assign IOI001=IO0101;assign IO0101=IIOlO1== 3'd1&& (I10l01|| IOO1O1);assign I0IIO1=IO0101;assign Il0lI1=IO1IO1&& Il10O1&& Il1IO1&& II1IO1
&& I11IO1&& I1O1I1== 3'd2&& IIOll1== 5'd0;assign I1I001=Il0lI1;assign I10101=IOII01|| I1I001;assign IOIlO1=I10101;assign I10l11=IO0lO1[2];assign IOIIl1=I10l11;assign I00111=IO0lO1[5];assign IIIIl1=I00111
;assign I00l11=IO0lO1[6];assign III0l1=I00l11;assign II0l11=IO0lO1[7];assign IlI0l1=II0l11;assign I10001=IO0lO1[8];assign IOIOO1=I10001;assign II0OI1=1'b0;assign IlIlO1=1'b0;assign Il0OI1=1'b0;assign I1IlO1
=1'b0;assign I10OI1=Il10O1&& IO1IO1&& I1O1I1== 3'd5;assign IOI1O1=I10OI1;assign I001I1=I00OI1;assign IIII01=I00OI1;assign Il0l11=1'd1;assign I1I0l1=1'd1;assign Il0001=loadArgs&& !IOO0O1;assign I10111=
Il0001;assign I00OI1=I0Ol01== 3'd1&& (I10101|| I1Ol01);assign IIIlO1=I00OI1;assign IO01I1=IO0OI1;assign I0II01=IO0OI1;assign IO0OI1=IIO101== 3'd1&& (I10101|| IOOOI1);assign I0IlO1=IO0OI1;assign IO00I1
=I1O1I1== 3'd1&& !II01I1&& !IIOOl1;assign I0I1O1=IO00I1;assign II0I01=I0I1O1|| IOI1O1;assign IlIOO1=II0I01;assign Il01l1=I0Ol01== 3'd2;assign I1III1=Il01l1;assign I101l1=I0Ol01== 3'd1&& !I10101&& !I1Ol01
;assign IOIlI1=I101l1;assign IO01l1=IOIlI1|| I1III1;assign I0III1=IO01l1;assign IO0O11=I00OI1|| I10101;assign I0IlI1=IO0O11;assign I001l1=IIO101== 3'd2;assign IIIII1=I001l1;assign II01l1=IIO101== 3'd1
&& !I10101&& !IOOOI1;assign IlIII1=II01l1;assign I10ll1=IlIII1|| IIIII1;assign IOIII1=I10ll1;assign I00O11=IO0OI1|| I10101;assign IIIlI1=I00O11;assign I000l1=I1OO01== 3'd2;assign III101=I000l1;assign II00l1
=I1OO01== 3'd1&& !II0l01&& !IIO001;assign IlI101=II00l1;assign IO0Ol1=IlI101|| III101;assign I0Il01=IO0Ol1;assign II0ll1=Il0101|| II0l01;assign IlI0I1=II0ll1;assign I10Ol1=IlO1O1== 3'd2;assign IOI101=
I10Ol1;assign IO00l1=IlO1O1== 3'd1&& !II0l01&& !I0OO01;assign I0I101=IO00l1;assign I101I1=I0I101|| IOI101;assign IOIl01=I101I1;assign I00ll1=II0101|| II0l01;assign III0I1=I00ll1;assign I00Ol1=IOOI01==
3'd2;assign IIIl01=I00Ol1;assign Il0Ol1=IOOI01== 3'd1&& !II0l01&& !IlOI01;assign I1Il01=Il0Ol1;assign Il01I1=I1Il01|| IlIl01|| IIIl01;assign I1II01=Il01I1;assign II0Il1=I0OIO1== 3'd2;assign IlIOI1=II0Il1
;assign Il0Il1=I0OIO1== 3'd1&& !I10l01&& !I1OIO1;assign I1IOI1=Il0Il1;assign I100l1=I1IOI1|| IlIOI1;assign IOIOI1=I100l1;assign I10Il1=I00101|| I10l01;assign IOI0I1=I10Il1;assign IO0Il1=IIOlO1== 3'd2;
assign I0IOI1=IO0Il1;assign I00Il1=IIOlO1== 3'd1&& !I10l01&& !IOO1O1;assign IIIOI1=I00Il1;assign Il00l1=IIIOI1|| I0IOI1;assign I1I101=Il00l1;assign IO0ll1=IO0101|| I10l01;assign I0I0I1=IO0ll1;assign Il0ll1
=IOOOO1|| II0l01;assign I1I0I1=Il0ll1;assign I10011=I1O0I1== 3'd2;assign IOIOl1=I10011;assign IO0I11=I1O0I1== 3'd1&& !Il0I01&& !IIOII1;assign I0IOl1=IO0I11;assign I10O11=I0IOl1|| IOIOl1;assign IOI1I1=
I10O11;assign II0I11=I00l01|| Il0I01;assign IlIOl1=II0I11;assign II0011=IlOOI1== 3'd2;assign IlI1I1=II0011;assign Il0011=IlOOI1== 3'd1&& !Il0I01&& !I0O0I1;assign I1I1I1=Il0011;assign Il0O11=I1I1I1|| IlI1I1
;assign I1IlI1=Il0O11;assign I00I11=IO0l01|| Il0I01;assign IIIOl1=I00I11;assign IO0011=IOOlI1== 3'd2;assign I0I1I1=IO0011;assign I00011=IOOlI1== 3'd1&& !Il0I01&& !IlOlI1;assign III1I1=I00011;assign II0O11
=III1I1|| I0I1I1;assign IlIlI1=II0O11;assign Il0I11=I10I01|| Il0I01;assign I1IOl1=Il0I11;assign IO0l11=I0OOO1|| II01I1;assign I0I0l1=IO0l11;assign I10I11=1'd1;assign IOI0l1=1'd1;assign III011=IO0lO1[6
]&& I01lO1&& IO1lO1;assign I0II11=IO0lO1[6]&& (I01lO1&& !IO1lO1|| !I01lO1&& II1lO1);assign IIII11=IO0lO1[7]&& I0l0l1&& IO0001[27:3]== 25'd33554431;assign IlII11=IO0lO1[6]&& !I01lO1&& !II1lO1;assign IOIl11
=IO0lO1[2]&& !I0OO11;assign I0Il11=IO0lO1[2]&& !Il0OO1;assign IIIl11=IO0lO1[6]&& I01lO1&& !IO1lO1;assign IlIl11=IO0lO1[8]&& I11I01;assign I1Il11=IO0lO1[7]&& I0l0l1;assign IlI011=!Il1I01&& I1l111;assign
I1I011=!(I0OO11& Il0OO1);assign IOII11=I01lO1&& !IO1lO1;assign I0IO11=I01lO1 ? 10'd896:IOlOl1;assign IIIO11=IOO0l1+10'd1;assign IlIO11=(IOOI11|| I1OIl1)? 10'b1111111111:((IO0001== 28'd0|| IIOOO1)? 10'd0
:{IOO0l1[9:8],~IOO0l1[7],IOO0l1[6:0]});assign I1IO11=(({IlO1l1[7],IlO1l1[7],IlO1l1}-{IO0OO1[7],IO0OO1[7],IO0OO1})-{5'b0,Il0lO1})+{5'b0,I001O1}-10'd2;assign IOI011=I0OIl1-5'd1;assign I1II11=!Il1I01&& (
IO1OI1 ? !I01I01:!IO1I01&& !I01OI1&& IOO1l1[30:23]== 8'hff& II1O01);assign I0I011=IIOll1-5'd1;assign III1l1=I1OO11<< IllOl1;assign I0Ill1={I1OO11,30'b0};assign IlI1l1={II1OI1,IOO1l1[22:0]};always @(I0OIl1
or Ill1O1 or IIl1O1 or I0l1O1 or IOl1O1 or I1llO1 or IlllO1 or IIllO1 or I0llO1 or IOllO1 or I1lIO1 or IllIO1 or IIlIO1 or I0lIO1 or IOlIO1 or I1l0O1 or Ill0O1 or IIl0O1 or I0l0O1 or IOl0O1 or I1lOO1 or IllOO1 or IIlOO1 or
I0lOO1 or IOlOO1 or I1I111 or IlI111 or III111 or I0I111)begin case (I0OIl1)5'd0:IOIll1=Ill1O1;5'd1:IOIll1=IIl1O1;5'd2:IOIll1=I0l1O1;5'd3:IOIll1=IOl1O1;5'd4:IOIll1=I1llO1;5'd5:IOIll1=IlllO1;5'd6:IOIll1=IIllO1
;5'd7:IOIll1=I0llO1;5'd8:IOIll1=IOllO1;5'd9:IOIll1=I1lIO1;5'd10:IOIll1=IllIO1;5'd11:IOIll1=IIlIO1;5'd12:IOIll1=I0lIO1;5'd13:IOIll1=IOlIO1;5'd14:IOIll1=I1l0O1;5'd15:IOIll1=Ill0O1;5'd16:IOIll1=IIl0O1;5'd17
:IOIll1=I0l0O1;5'd18:IOIll1=IOl0O1;5'd19:IOIll1=I1lOO1;5'd20:IOIll1=IllOO1;5'd21:IOIll1=IIlOO1;5'd22:IOIll1=I0lOO1;5'd23:IOIll1=IOlOO1;5'd24:IOIll1=I1I111;5'd25:IOIll1=IlI111;5'd26:IOIll1=III111;5'd27
:IOIll1=I0I111;default :IOIll1=54'd0;endcase end assign IIIll1={I1Ol11[26:0],1'b0};assign IlIll1={I1Ol11[26:0],1'b1};assign I1I1l1=I000O1<< I1lOl1;assign IOIO11={Il1OI1,IIO111[22:0]};assign I1Ill1=I01lO1
? (I0lOl1[9]? I1llI1:IOl1I1):I0l1I1;assign IOI1l1=IOOI11 ? Ill1I1:28'd0;assign I0I1l1=(IO0001[27:3]== 25'd33554431)? 28'd0:IIl1I1;assign I0OOO1=IOII01|| I1I001|| IIIO01|| I0IO01|| III1O1;assign IOOOO1=
I1IO01|| IlIO01;assign IlOOO1=III011|| IlI011;assign I1OOO1=IO0lO1[6]&& I01lO1&& IO1lO1|| IO0lO1[0];assign I0O0O1=I10111;assign IIO0O1=IO0lO1[8]|| I10111;assign I1O0O1=IO0lO1[2]? I1I011:IOII11;assign IOOIO1
=IO0lO1[2]|| IO0lO1[6];assign IIOIO1=I100l1 ? 3'd1:3'd2;assign IlOIO1=I1IOI1|| IlIOI1|| I0I001;assign IOOlO1=!I00101;assign I0OlO1=I10Il1;assign IlOlO1=Il00l1 ? 3'd1:3'd2;assign I1OlO1=IIIOI1|| I0IOI1||
IOI001;assign I0O1O1=!IO0101;assign IIO1O1=IO0ll1;assign I1O1O1=I101I1 ? 3'd1:3'd2;assign IOOO01=I0I101|| IOI101|| III001;assign IIOO01=!II0101;assign IlOO01=I00ll1;assign IOO001=IO0Ol1 ? 3'd1:3'd2;assign
I0O001=IlI101|| III101|| IlI001;assign IlO001=!Il0101;assign I1O001=II0ll1;always @(Il01I1 or IlIO01 or I1IO01)begin case (1'b1)Il01I1:I0OI01=3'd1;IlIO01:I0OI01=3'd2;I1IO01:I0OI01=3'd3;default :I0OI01=3'b010
;endcase end assign IIOI01=I1Il01|| IlIl01|| IIIl01|| IlIO01|| I1IO01;assign I1OI01=!IOOOO1;assign IOOl01=Il0ll1;assign IIOl01=IO01l1 ? 3'd1:3'd2;assign IlOl01=IOIlI1|| I1III1|| IIII01;assign IOO101=!I00OI1
;assign I0O101=IO0O11;assign IlO101=I10ll1 ? 3'd1:3'd2;assign I1O101=IlIII1|| IIIII1|| I0II01;assign I0OOI1=!IO0OI1;assign IIOOI1=I00O11;assign I1OOI1=Il0O11 ? 3'd1:3'd2;assign IOO0I1=I1I1I1|| IlI1I1|| I1I1O1
;assign IIO0I1=!IO0l01;assign IlO0I1=I00I11;assign IOOII1=I10O11 ? 3'd1:3'd2;assign I0OII1=I0IOl1|| IOIOl1|| IOIO01;assign IlOII1=!I00l01;assign I1OII1=II0I11;assign I0OlI1=II0O11 ? 3'd1:3'd2;assign IIOlI1
=III1I1|| I0I1I1|| IlI1O1;assign I1OlI1=!I10I01;assign IOO1I1=Il0I11;assign IIO1I1=IO0111;assign IlO1I1=1'd1;always @(II0I01 or III1O1 or II0l01 or I10101)begin case (1'b1)II0I01:IOOOl1=3'd1;III1O1:IOOOl1
=3'd2;II0l01:IOOOl1=3'd3;I10101:IOOOl1=3'd5;default :IOOOl1=3'b010;endcase end assign I0OOl1=I0I1O1|| IOI1O1|| III1O1|| IIIO01|| I0IO01|| IOII01|| I1I001;assign IlOOl1=!I0OOO1;assign I1OOl1=IO0l11;always
@(I0II11 or I0IO11 or IIII11 or IIIO11 or IO0lO1 or IlIO11 or I0IIl1 or I1IO11)begin case (1'b1)I0II11:I0O0l1=I0IO11;IIII11:I0O0l1=IIIO11;IO0lO1[8]:I0O0l1=IlIO11;I0IIl1:I0O0l1=I1IO11;default :I0O0l1=10'b1010101010
;endcase end assign IIO0l1=I0II11|| IO0lO1[7]&& I0l0l1&& IO0001[27:3]== 25'd33554431|| IO0lO1[8]|| I0IIl1;assign I1O0l1={26'd0,I1Ol11};assign IOOIl1=IO0OI1;assign IIOIl1=III001 ? IOI011:5'd27;assign IlOIl1
=III001|| IlI1O1;assign IOOll1=IlII11|| I1II11;assign I0Oll1=IO0lO1[6]&& !I01lO1&& !II1lO1|| IO0lO1[0];assign IlOll1=IlI001 ? I0I011:5'd28;assign I1Oll1=IlI001|| I1I1O1;assign I0O1l1=leftArg;assign IIO1l1
=Il0001;assign I1O1l1=I01O01 ? 8'h81:IOO1l1[30:23]-8'd128;assign IOOO11=I00I01;assign IIOO11=II1OI1;assign IlOO11=I00I01;assign IOO011=IOIl11 ? III1l1:IlI1l1;assign I0O011=IO0lO1[2]&& !I0OO11|| IO0lO1[1
];assign IlO011=IOIO01 ? I0Ill1:IOIll1;assign I1O011=IOIO01|| I0I001;assign I0OI11=Il1I01|| IOl0l1;assign IIOI11=IO0I01;assign I1OI11=I1l1O1[4:0]-5'd26;assign IOOl11=I00111;assign IIOl11=29'h0;assign IlOl11
=1'b0;assign IOO111=IlIO01 ? IIIll1:IlIll1;assign I0O111=IlIO01|| IOI001;assign IlO111=rightArg;assign I1O111=Il0001;assign I00OO1=I01l01 ? 8'h81:IIO111[30:23]-8'd128;assign II0OO1=I00I01;assign I10OO1=
Il1OI1;assign IO00O1=I00I01;assign II00O1=I0Il11 ? I1I1l1:IOIO11;assign Il00O1=IO0lO1[2]&& !Il0OO1|| IO0lO1[1];assign IO0IO1=1'b0;assign I00IO1=1'b0;assign Il0IO1=1'b0;assign I10IO1=1'b0;assign I00lO1=
IO0lO1[8]? 9'h0:{IO0lO1[7:0],IOO0O1&& IO0lO1== 9'd0};assign II0lO1=IO0lO1[8]|| IOO0O1&& IO0lO1== 9'd0|| IO0lO1[7:0]!= 8'd0&& (!IO0lO1[4]|| I00OI1);assign I10lO1=I0OO11 ? 5'h0:IllOl1;assign IO01O1=I10l11
;assign II01O1=Il0OO1 ? 5'h0:I1lOl1;assign Il01O1=I10l11;assign IO0O01=IOO1l1[31]^ IIO111[31];assign I00O01=I00I01;assign Il0O01=!IIIl11;assign I10O01=IO0lO1[6]&& I01lO1&& !IO1lO1|| IO0lO1[5];always @(
I0II11 or I1Ill1 or IlIl11 or IOI1l1 or I1Il11 or I0I1l1 or IO0lO1 or IlO0l1)begin case (1'b1)I0II11:I00001=I1Ill1;IlIl11:I00001=IOI1l1;I1Il11:I00001=I0I1l1;IO0lO1[5]:I00001=IlO0l1[27:0];default :I00001=28'b1010101010101010101010101010
;endcase end assign II0001=I0II11|| IO0lO1[8]&& I11I01|| IO0lO1[7]&& I0l0l1|| IO0lO1[5];assign I1l1O1=(IlO0l1[0]&& I1lIl1)? 32'd0:((IlO0l1[1]&& (!IlO0l1[2]|| Il11O1)&& Illll1&& I1lll1)? 32'd1:Ill001);
assign IOlO01=(IlO0l1[11]&& Ill0l1&& I1l0l1)? 32'd11:I0lO01;assign I0lO01=(IlO0l1[12]&& I1l0l1)? 32'd12:((IlO0l1[13]&& (!IlO0l1[14]|| I11lO1)&& IOlIl1&& I0lIl1)? 32'd13:IIlO01);assign IIlO01=(IlO0l1[14
]&& IOlIl1&& I0lIl1)? 32'd14:IllO01;assign IllO01=(IlO0l1[15]&& I0lIl1)? 32'd15:((IlO0l1[16]&& (!IlO0l1[17]|| IO11O1)&& IIlIl1&& IllIl1)? 32'd16:I1lO01);assign I1lO01=(IlO0l1[17]&& IIlIl1&& IllIl1)? 32'd17
:IOl001;assign IOl001=(IlO0l1[18]&& IllIl1)? 32'd18:((IlO0l1[19]&& (!IlO0l1[20]|| I011O1)&& IOlll1&& I0lll1)? 32'd19:I0l001);assign I0l001=(IlO0l1[20]&& IOlll1&& I0lll1)? 32'd20:IIl001;assign IIl001=(
IlO0l1[21]&& I0lll1)? 32'd21:((IlO0l1[22]&& (!IlO0l1[23]|| II11O1)&& IIlll1)? 32'd22:((IlO0l1[23]&& IIlll1)? 32'd23:((IlO0l1[24]&& !IlO0l1[25]&& !IlO0l1[26]&& !IlO0l1[27])? 32'd24:((IlO0l1[25]&& !IlO0l1
[26]&& !IlO0l1[27])? 32'd25:((IlO0l1[26]&& !IlO0l1[27])? 32'd26:(IlO0l1[27]? 32'd27:32'd0))))));assign Ill001=(IlO0l1[2]&& Illll1&& I1lll1)? 32'd2:I1l001;assign I1l001=(IlO0l1[3]&& I1lll1)? 32'd3:((IlO0l1
[4]&& (!IlO0l1[5]|| I111O1)&& IOl1l1&& I0l1l1)? 32'd4:IOlI01);assign IOlI01=(IlO0l1[5]&& IOl1l1&& I0l1l1)? 32'd5:I0lI01;assign I0lI01=(IlO0l1[6]&& I0l1l1)? 32'd6:((IlO0l1[7]&& (!IlO0l1[8]|| IO1O01)&& IIl1l1
&& IIl0l1)? 32'd7:IIlI01);assign IIlI01=(IlO0l1[8]&& IIl1l1&& IIl0l1)? 32'd8:IllI01;assign IllI01=(IlO0l1[9]&& IIl0l1)? 32'd9:((IlO0l1[10]&& (!IlO0l1[11]|| Il1lO1)&& Ill0l1&& I1l0l1)? 32'd10:IOlO01);assign
I1lI01=Il1O01 ? 32'd0:I0l101;assign IOll01=(I1OO11[10]&& Ill1l1&& I1l1l1)? 32'd10:I0ll01;assign I0ll01=(I1OO11[11]&& I1l1l1)? 32'd11:((I1OO11[12]&& (!I1OO11[13]|| IO1001)&& IOlO11&& I0lO11)? 32'd12:IIll01
);assign IIll01=(I1OO11[13]&& IOlO11&& I0lO11)? 32'd13:Illl01;assign Illl01=(I1OO11[14]&& I0lO11)? 32'd14:((I1OO11[15]&& (!I1OO11[16]|| I01001)&& IIlO11&& IllO11)? 32'd15:I1ll01);assign I1ll01=(I1OO11
[16]&& IIlO11&& IllO11)? 32'd16:IOl101;assign IOl101=(I1OO11[17]&& IllO11)? 32'd17:((I1OO11[18]&& (!I1OO11[19]|| II1001)&& I1lO11)? 32'd18:((I1OO11[19]&& I1lO11)? 32'd19:((I1OO11[20]&& !I1OO11[21]&& !
I1OO11[22]&& !I1OO11[23])? 32'd20:((I1OO11[21]&& !I1OO11[22]&& !I1OO11[23])? 32'd21:((I1OO11[22]&& !I1OO11[23])? 32'd22:(I1OO11[23]? 32'd23:32'd0))))));assign I0l101=(I1OO11[1]&& IOl011&& I0l011)? 32'd1
:IIl101;assign IIl101=(I1OO11[2]&& I0l011)? 32'd2:((I1OO11[3]&& (!I1OO11[4]|| Il1001)&& IIl011&& Ill011)? 32'd3:Ill101);assign Ill101=(I1OO11[4]&& IIl011&& Ill011)? 32'd4:I1l101;assign I1l101=(I1OO11[
5]&& Ill011)? 32'd5:((I1OO11[6]&& (!I1OO11[7]|| I11001)&& I1l011&& IOlI11)? 32'd6:IOlOI1);assign IOlOI1=(I1OO11[7]&& I1l011&& IOlI11)? 32'd7:I0lOI1;assign I0lOI1=(I1OO11[8]&& IOlI11)? 32'd8:((I1OO11[9
]&& (!I1OO11[10]|| I11O01)&& Ill1l1&& I1l1l1)? 32'd9:IOll01);assign IIlOI1=Il1l01 ? 32'd0:I1l0I1;assign IllOI1=(I000O1[10]&& I0lI11&& IIlI11)? 32'd10:I1lOI1;assign I1lOI1=(I000O1[11]&& IIlI11)? 32'd11:
((I000O1[12]&& (!I000O1[13]|| IO1101)&& IllI11&& I1lI11)? 32'd12:IOl0I1);assign IOl0I1=(I000O1[13]&& IllI11&& I1lI11)? 32'd13:I0l0I1;assign I0l0I1=(I000O1[14]&& I1lI11)? 32'd14:((I000O1[15]&& (!I000O1
[16]|| I01101)&& IOll11&& I0ll11)? 32'd15:IIl0I1);assign IIl0I1=(I000O1[16]&& IOll11&& I0ll11)? 32'd16:Ill0I1;assign Ill0I1=(I000O1[17]&& I0ll11)? 32'd17:((I000O1[18]&& (!I000O1[19]|| II1101)&& IIll11
)? 32'd18:((I000O1[19]&& IIll11)? 32'd19:((I000O1[20]&& !I000O1[21]&& !I000O1[22]&& !I000O1[23])? 32'd20:((I000O1[21]&& !I000O1[22]&& !I000O1[23])? 32'd21:((I000O1[22]&& !I000O1[23])? 32'd22:(I000O1[23
]? 32'd23:32'd0))))));assign I1l0I1=(I000O1[1]&& Illl11&& I1ll11)? 32'd1:IOlII1;assign IOlII1=(I000O1[2]&& I1ll11)? 32'd2:((I000O1[3]&& (!I000O1[4]|| Il1101)&& IOl111&& I0l111)? 32'd3:I0lII1);assign I0lII1
=(I000O1[4]&& IOl111&& I0l111)? 32'd4:IIlII1;assign IIlII1=(I000O1[5]&& I0l111)? 32'd5:((I000O1[6]&& (!I000O1[7]|| I11101)&& IIl111&& Ill111)? 32'd6:IllII1);assign IllII1=(I000O1[7]&& IIl111&& Ill111)
? 32'd7:I1lII1;assign I1lII1=(I000O1[8]&& Ill111)? 32'd8:((I000O1[9]&& (!I000O1[10]|| I11l01)&& I0lI11&& IIlI11)? 32'd9:IllOI1);assign IOl0l1=IO1OI1 ? I01I01:!IO1I01&& I01OI1&& IOO1l1[30:23]== 8'hff;assign
I0l0l1=(IO0001[2]&& IO0001[1:0]== 2'b0)? IO0001[3]|| II0O01:IO0001[2]&& IO0001[1:0]!= 2'b0;assign IIl0l1=(!IlO0l1[10]|| IlO0l1[11]|| Il1lO1)&& (!IlO0l1[11]|| Il1lO1)&& Ill0l1&& I1l0l1;assign Ill0l1=!IlO0l1
[12]|| IlO0l1[13]|| IlO0l1[14]|| I11lO1;assign I1l0l1=(!IlO0l1[13]|| IlO0l1[14]|| I11lO1)&& (!IlO0l1[14]|| I11lO1)&& IOlIl1&& I0lIl1;assign IOlIl1=!IlO0l1[15]|| IlO0l1[16]|| IlO0l1[17]|| IO11O1;assign
I0lIl1=(!IlO0l1[16]|| IlO0l1[17]|| IO11O1)&& (!IlO0l1[17]|| IO11O1)&& IIlIl1&& IllIl1;assign IIlIl1=!IlO0l1[18]|| IlO0l1[19]|| IlO0l1[20]|| I011O1;assign IllIl1=(!IlO0l1[19]|| IlO0l1[20]|| I011O1)&& (
!IlO0l1[20]|| I011O1)&& IOlll1&& I0lll1;assign I1lIl1=(!IlO0l1[1]|| IlO0l1[2]|| Il11O1)&& (!IlO0l1[2]|| Il11O1)&& Illll1&& I1lll1;assign IOlll1=!IlO0l1[21]|| IlO0l1[22]|| IlO0l1[23]|| II11O1;assign I0lll1
=(!IlO0l1[22]|| IlO0l1[23]|| II11O1)&& (!IlO0l1[23]|| II11O1)&& IIlll1;assign IIlll1=(!IlO0l1[24]|| IlO0l1[25]|| IlO0l1[26]|| IlO0l1[27])&& !IlO0l1[25]&& !IlO0l1[26]&& !IlO0l1[27];assign Illll1=!IlO0l1
[3]|| IlO0l1[4]|| IlO0l1[5]|| I111O1;assign I1lll1=(!IlO0l1[4]|| IlO0l1[5]|| I111O1)&& (!IlO0l1[5]|| I111O1)&& IOl1l1&& I0l1l1;assign IOl1l1=!IlO0l1[6]|| IlO0l1[7]|| IlO0l1[8]|| IO1O01;assign I0l1l1=(
!IlO0l1[7]|| IlO0l1[8]|| IO1O01)&& (!IlO0l1[8]|| IO1O01)&& IIl1l1&& IIl0l1;assign IIl1l1=!IlO0l1[9]|| IlO0l1[10]|| IlO0l1[11]|| Il1lO1;assign Ill1l1=!I1OO11[11]|| I1OO11[12]|| I1OO11[13]|| IO1001;assign
I1l1l1=(!I1OO11[12]|| I1OO11[13]|| IO1001)&& (!I1OO11[13]|| IO1001)&& IOlO11&& I0lO11;assign IOlO11=!I1OO11[14]|| I1OO11[15]|| I1OO11[16]|| I01001;assign I0lO11=(!I1OO11[15]|| I1OO11[16]|| I01001)&& (
!I1OO11[16]|| I01001)&& IIlO11&& IllO11;assign IIlO11=!I1OO11[17]|| I1OO11[18]|| I1OO11[19]|| II1001;assign IllO11=(!I1OO11[18]|| I1OO11[19]|| II1001)&& (!I1OO11[19]|| II1001)&& I1lO11;assign I1lO11=(
!I1OO11[20]|| I1OO11[21]|| I1OO11[22]|| I1OO11[23])&& !I1OO11[21]&& !I1OO11[22]&& !I1OO11[23];assign IOl011=!I1OO11[2]|| I1OO11[3]|| I1OO11[4]|| Il1001;assign I0l011=(!I1OO11[3]|| I1OO11[4]|| Il1001)&&
(!I1OO11[4]|| Il1001)&& IIl011&& Ill011;assign IIl011=!I1OO11[5]|| I1OO11[6]|| I1OO11[7]|| I11001;assign Ill011=(!I1OO11[6]|| I1OO11[7]|| I11001)&& (!I1OO11[7]|| I11001)&& I1l011&& IOlI11;assign I1l011
=!I1OO11[8]|| I1OO11[9]|| I1OO11[10]|| I11O01;assign IOlI11=(!I1OO11[9]|| I1OO11[10]|| I11O01)&& (!I1OO11[10]|| I11O01)&& Ill1l1&& I1l1l1;assign I0lI11=!I000O1[11]|| I000O1[12]|| I000O1[13]|| IO1101;assign
IIlI11=(!I000O1[12]|| I000O1[13]|| IO1101)&& (!I000O1[13]|| IO1101)&& IllI11&& I1lI11;assign IllI11=!I000O1[14]|| I000O1[15]|| I000O1[16]|| I01101;assign I1lI11=(!I000O1[15]|| I000O1[16]|| I01101)&& (
!I000O1[16]|| I01101)&& IOll11&& I0ll11;assign IOll11=!I000O1[17]|| I000O1[18]|| I000O1[19]|| II1101;assign I0ll11=(!I000O1[18]|| I000O1[19]|| II1101)&& (!I000O1[19]|| II1101)&& IIll11;assign IIll11=(
!I000O1[20]|| I000O1[21]|| I000O1[22]|| I000O1[23])&& !I000O1[21]&& !I000O1[22]&& !I000O1[23];assign Illl11=!I000O1[2]|| I000O1[3]|| I000O1[4]|| Il1101;assign I1ll11=(!I000O1[3]|| I000O1[4]|| Il1101)&&
(!I000O1[4]|| Il1101)&& IOl111&& I0l111;assign IOl111=!I000O1[5]|| I000O1[6]|| I000O1[7]|| I11101;assign I0l111=(!I000O1[6]|| I000O1[7]|| I11101)&& (!I000O1[7]|| I11101)&& IIl111&& Ill111;assign IIl111
=!I000O1[8]|| I000O1[9]|| I000O1[10]|| I11l01;assign Ill111=(!I000O1[9]|| I000O1[10]|| I11l01)&& (!I000O1[10]|| I11l01)&& I0lI11&& IIlI11;assign I1l111=!IO1OI1&& (IO1I01|| I01OI1&& IOO1l1[30:23]!= 8'hff
);assign IOllI1=I0llI1-{2'b0,I1l1I1};assign IO1OO1=I0OIO1== 3'd2|| I0OIO1== 3'd1&& !I1OIO1;assign I01OO1=IO1OO1&& Il1OO1&& I010O1&& I11OO1&& IO10O1&& Il1IO1&& II1IO1&& I11IO1;assign II1OO1=IO1OO1&& Il1OO1
&& I010O1&& I11OO1&& IO10O1;assign Il1OO1=IIOlO1== 3'd2|| IIOlO1== 3'd1&& !IOO1O1;assign I11OO1=IlO1O1== 3'd2|| IlO1O1== 3'd1&& !I0OO01;assign IO10O1=I1OO01== 3'd2|| I1OO01== 3'd1&& !IIO001;assign I010O1
=IOOI01== 3'd2|| IOOI01== 3'd3|| IOOI01== 3'd1&& !IlOI01;assign II10O1=IOOI01== 3'd1&& (II0l01|| IlOI01)&& !IOllI1[28];assign Il10O1=I0Ol01== 3'd2|| I0Ol01== 3'd1&& !I1Ol01;assign I110O1=Il10O1&& IO1IO1
&& (I1O1I1== 3'd5|| I1O1I1== 3'd1&& !IIOOl1);assign IO1IO1=IIO101== 3'd2|| IIO101== 3'd1&& !IOOOI1;assign I01IO1=IO1IO1&& Il10O1&& IO10O1&& I11OO1&& IO1OO1&& Il1OO1&& I010O1;assign II1IO1=IlOOI1== 3'd2
|| IlOOI1== 3'd1&& !I0O0I1;assign Il1IO1=I1O0I1== 3'd2|| I1O0I1== 3'd1&& !IIOII1;assign I11IO1=IOOlI1== 3'd2|| IOOlI1== 3'd1&& !IlOlI1;assign IO1lO1=(IOlOl1^ 10'h200)<10'd361;assign I01lO1=(IOlOl1^ 10'h200
)<= 10'd384;assign II1lO1=(IOlOl1^ 10'h200)<= 10'd638;assign IOlOl1=IOO0l1+{5'd0,IlOI11};assign I0lOl1=IOO0l1+10'd127;assign Il1lO1=IlO0l1[12]|| IlO0l1[13]|| IlO0l1[14]|| I11lO1;assign I11lO1=IlO0l1[15
]|| IlO0l1[16]|| IlO0l1[17]|| IO11O1;assign IO11O1=IlO0l1[18]|| IlO0l1[19]|| IlO0l1[20]|| I011O1;assign I011O1=IlO0l1[21]|| IlO0l1[22]|| IlO0l1[23]|| II11O1;assign II11O1=IlO0l1[24]|| IlO0l1[25]|| IlO0l1
[26]|| IlO0l1[27];assign Il11O1=IlO0l1[3]|| IlO0l1[4]|| IlO0l1[5]|| I111O1;assign I111O1=IlO0l1[6]|| IlO0l1[7]|| IlO0l1[8]|| IO1O01;assign IO1O01=IlO0l1[9]|| IlO0l1[10]|| IlO0l1[11]|| Il1lO1;assign I01O01
=IOO1l1[30:23]== 8'h0;assign II1O01=IOO1l1[22:0]== 23'b0;assign Il1O01=I1OO11[0]&& (!I1OO11[1]|| I1OO11[2]|| I1OO11[3]|| I1OO11[4]|| Il1001)&& IOl011&& I0l011;assign I11O01=I1OO11[11]|| I1OO11[12]|| I1OO11
[13]|| IO1001;assign IO1001=I1OO11[14]|| I1OO11[15]|| I1OO11[16]|| I01001;assign I01001=I1OO11[17]|| I1OO11[18]|| I1OO11[19]|| II1001;assign II1001=I1OO11[20]|| I1OO11[21]|| I1OO11[22]|| I1OO11[23];assign
Il1001=I1OO11[5]|| I1OO11[6]|| I1OO11[7]|| I11001;assign I11001=I1OO11[8]|| I1OO11[9]|| I1OO11[10]|| I11O01;assign IO1I01=I01O01& II1O01;assign I01I01=IO1I01| II1I01;assign II1I01=IOO1l1[30:23]== 8'hff
& ~II1O01;assign Il1I01=II1I01| IO1l01& ~II1l01;assign I11I01=IOOI11|| I1OIl1|| IO0001== 28'd0|| IIOOO1;assign I0llI1={1'b0,IOI111[27:0]};assign IIllI1={2'b0,IIO011[53:27]};assign IlllI1={1'd0,IIO011[
53:26]};assign I0I111={IOllI1[26:0],IIO011[26:0]};assign III111={IIO011[53],IOllI1[26:0],IIO011[25:0]};assign IlI111={IIO011[53:52],IOllI1[26:0],IIO011[24:0]};assign I1I111={IIO011[53:51],IOllI1[26:0]
,IIO011[23:0]};assign IOlOO1={IIO011[53:50],IOllI1[26:0],IIO011[22:0]};assign I0lOO1={IIO011[53:49],IOllI1[26:0],IIO011[21:0]};assign IIlOO1={IIO011[53:48],IOllI1[26:0],IIO011[20:0]};assign IllOO1={IIO011
[53:47],IOllI1[26:0],IIO011[19:0]};assign I1lOO1={IIO011[53:46],IOllI1[26:0],IIO011[18:0]};assign IOl0O1={IIO011[53:45],IOllI1[26:0],IIO011[17:0]};assign I0l0O1={IIO011[53:44],IOllI1[26:0],IIO011[16:0
]};assign IIl0O1={IIO011[53:43],IOllI1[26:0],IIO011[15:0]};assign Ill0O1={IIO011[53:42],IOllI1[26:0],IIO011[14:0]};assign I1l0O1={IIO011[53:41],IOllI1[26:0],IIO011[13:0]};assign IOlIO1={IIO011[53:40],
IOllI1[26:0],IIO011[12:0]};assign I0lIO1={IIO011[53:39],IOllI1[26:0],IIO011[11:0]};assign IIlIO1={IIO011[53:38],IOllI1[26:0],IIO011[10:0]};assign IllIO1={IIO011[53:37],IOllI1[26:0],IIO011[9:0]};assign
I1lIO1={IIO011[53:36],IOllI1[26:0],IIO011[8:0]};assign IOllO1={IIO011[53:35],IOllI1[26:0],IIO011[7:0]};assign I0llO1={IIO011[53:34],IOllI1[26:0],IIO011[6:0]};assign IIllO1={IIO011[53:33],IOllI1[26:0],
IIO011[5:0]};assign IlllO1={IIO011[53:32],IOllI1[26:0],IIO011[4:0]};assign I1llO1={IIO011[53:31],IOllI1[26:0],IIO011[3:0]};assign IOl1O1={IIO011[53:30],IOllI1[26:0],IIO011[2:0]};assign I0l1O1={IIO011[
53:29],IOllI1[26:0],IIO011[1:0]};assign IIl1O1={IIO011[53:28],IOllI1[26:0],IIO011[0]};assign Ill1O1={IIO011[53:27],IOllI1[26:0]};assign IO1l01=IIO111[30:23]== 8'hff;assign I01l01=IIO111[30:23]== 8'h0;
assign II1l01=IIO111[22:0]== 23'b0;assign I1l1I1={I000O1,3'b0};assign Il1l01=I000O1[0]&& (!I000O1[1]|| I000O1[2]|| I000O1[3]|| I000O1[4]|| Il1101)&& Illl11&& I1ll11;assign I11l01=I000O1[11]|| I000O1[12
]|| I000O1[13]|| IO1101;assign IO1101=I000O1[14]|| I000O1[15]|| I000O1[16]|| I01101;assign I01101=I000O1[17]|| I000O1[18]|| I000O1[19]|| II1101;assign II1101=I000O1[20]|| I000O1[21]|| I000O1[22]|| I000O1
[23];assign Il1101=I000O1[5]|| I000O1[6]|| I000O1[7]|| I11101;assign I11101=I000O1[8]|| I000O1[9]|| I000O1[10]|| I11l01;assign IO1OI1=I01l01& II1l01;assign I01OI1=IO1l01& II1l01;assign IllOl1=5'd23-I1lI01
[4:0];assign I1lOl1=5'd23-IIlOI1[4:0];assign II1OI1=~I01O01;assign Il1OI1=~I01l01;assign I1llI1=IO0001>> IIlOl1;assign IIlOl1=I0lOl1[9]? -I0lOl1:I0lOl1;assign IOl1I1=IO0001<< IIlOl1;assign I0l1I1=IO0001
>> IlOI11;assign IIl1I1={IO0001[27:3]+25'd1,IO0001[2:0]};assign Ill1I1={IO0001[27:26],1'b1,IO0001[24:0]};always @(I0OIl1 or IIO011 or IlllI1 or IIllI1)begin case (I0OIl1)5'd0:IOI111=IIO011[28:0];5'd1:IOI111
=IIO011[29:1];5'd2:IOI111=IIO011[30:2];5'd3:IOI111=IIO011[31:3];5'd4:IOI111=IIO011[32:4];5'd5:IOI111=IIO011[33:5];5'd6:IOI111=IIO011[34:6];5'd7:IOI111=IIO011[35:7];5'd8:IOI111=IIO011[36:8];5'd9:IOI111
=IIO011[37:9];5'd10:IOI111=IIO011[38:10];5'd11:IOI111=IIO011[39:11];5'd12:IOI111=IIO011[40:12];5'd13:IOI111=IIO011[41:13];5'd14:IOI111=IIO011[42:14];5'd15:IOI111=IIO011[43:15];5'd16:IOI111=IIO011[44:16
];5'd17:IOI111=IIO011[45:17];5'd18:IOI111=IIO011[46:18];5'd19:IOI111=IIO011[47:19];5'd20:IOI111=IIO011[48:20];5'd21:IOI111=IIO011[49:21];5'd22:IOI111=IIO011[50:22];5'd23:IOI111=IIO011[51:23];5'd24:IOI111
=IIO011[52:24];5'd25:IOI111=IIO011[53:25];5'd26:IOI111=IlllI1;5'd27:IOI111=IIllI1;default :IOI111=29'd0;endcase end always @(posedge CLK)begin if(!nRST)begin IIOOO1<= 1'b0;IOO0O1<= 1'b0;IlO0O1<= 1'd0;
I0OIO1<= 3'd1;I1OIO1<= 1'd0;IIOlO1<= 3'd1;IOO1O1<= 1'd0;IlO1O1<= 3'd1;I0OO01<= 1'd0;I1OO01<= 3'd1;IIO001<= 1'd0;IOOI01<= 3'd1;IlOI01<= 1'd0;I0Ol01<= 3'd1;I1Ol01<= 1'd0;IIO101<= 3'd1;IOOOI1<= 1'd0;IlOOI1
<= 3'd1;I0O0I1<= 1'd0;I1O0I1<= 3'd1;IIOII1<= 1'd0;IOOlI1<= 3'd1;IlOlI1<= 1'd0;I0O1I1<= 1'd0;I1O1I1<= 3'd1;IIOOl1<= 1'd0;IOO0l1<= 10'h0;IlO0l1<= 54'h0;I0OIl1<= 5'h0;I1OIl1<= 1'b0;IIOll1<= 5'h0;IOO1l1<=
32'd0;IlO1l1<= 8'h0;I0OO11<= 1'd0;I1OO11<= 24'h0;IIO011<= 54'h0;IOOI11<= 1'b0;IlOI11<= 5'h0;I0Ol11<= 29'h0;I1Ol11<= 28'h0;IIO111<= 32'd0;IO0OO1<= 8'h0;Il0OO1<= 1'd0;I000O1<= 24'h0;I100O1<= 1'd0;II0IO1
<= 1'd0;IO0lO1<= 9'd0;Il0lO1<= 5'h0;I001O1<= 5'h0;I101O1<= 1'd0;II0O01<= 1'd0;IO0001<= 28'h0;end else begin if(I1OOO1)IIOOO1<= IlOOO1;if(IIO0O1)IOO0O1<= I0O0O1;if(IOOIO1)IlO0O1<= I1O0O1;if(IlOIO1)I0OIO1
<= IIOIO1;if(I0OlO1)I1OIO1<= IOOlO1;if(I1OlO1)IIOlO1<= IlOlO1;if(IIO1O1)IOO1O1<= I0O1O1;if(IOOO01)IlO1O1<= I1O1O1;if(IlOO01)I0OO01<= IIOO01;if(I0O001)I1OO01<= IOO001;if(I1O001)IIO001<= IlO001;if(IIOI01
)IOOI01<= I0OI01;if(IOOl01)IlOI01<= I1OI01;if(IlOl01)I0Ol01<= IIOl01;if(I0O101)I1Ol01<= IOO101;if(I1O101)IIO101<= IlO101;if(IIOOI1)IOOOI1<= I0OOI1;if(IOO0I1)IlOOI1<= I1OOI1;if(IlO0I1)I0O0I1<= IIO0I1;if
(I0OII1)I1O0I1<= IOOII1;if(I1OII1)IIOII1<= IlOII1;if(IIOlI1)IOOlI1<= I0OlI1;if(IOO1I1)IlOlI1<= I1OlI1;if(IlO1I1)I0O1I1<= IIO1I1;if(I0OOl1)I1O1I1<= IOOOl1;if(I1OOl1)IIOOl1<= IlOOl1;if(IIO0l1)IOO0l1<= I0O0l1
;if(IOOIl1)IlO0l1<= I1O0l1;if(IlOIl1)I0OIl1<= IIOIl1;if(I0Oll1)I1OIl1<= IOOll1;if(I1Oll1)IIOll1<= IlOll1;if(IIO1l1)IOO1l1<= I0O1l1;if(IOOO11)IlO1l1<= I1O1l1;if(IlOO11)I0OO11<= IIOO11;if(I0O011)I1OO11<=
IOO011;if(I1O011)IIO011<= IlO011;if(IIOI11)IOOI11<= I0OI11;if(IOOl11)IlOI11<= I1OI11;if(IlOl11)I0Ol11<= IIOl11;if(I0O111)I1Ol11<= IOO111;if(I1O111)IIO111<= IlO111;if(II0OO1)IO0OO1<= I00OO1;if(IO00O1)Il0OO1
<= I10OO1;if(Il00O1)I000O1<= II00O1;if(I00IO1)I100O1<= IO0IO1;if(I10IO1)II0IO1<= Il0IO1;if(II0lO1)IO0lO1<= I00lO1;if(IO01O1)Il0lO1<= I10lO1;if(Il01O1)I001O1<= II01O1;if(I00O01)I101O1<= IO0O01;if(I10O01
)II0O01<= Il0O01;if(II0001)IO0001<= I00001;end end endmodule
