//////////////////////////////////////////////////////////////////
//                                                             
// Copyright (C) 2009 Pulse Logic
//                    info@pulselogic.com.pl                   
//                                                             
// This source file may be used and distributed without        
// restriction provided that this copyright statement is not   
// removed from the file and that any derivative work contains 
// the original copyright notice and the associated disclaimer.
//                                                             
//     THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY     
// EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED   
// TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS   
// FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL THE AUTHOR      
// OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,         
// INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES    
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE   
// GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR        
// BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF  
// LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR TORT  
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  
// OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE         
// POSSIBILITY OF SUCH DAMAGE.                                 
//                                                             
//////////////////////////////////////////////////////////////////
//
// Title       : Float32Sqrt
// Design      : Float32 RTL Library
// Company     : Pulse Logic
//
//////////////////////////////////////////////////////////////////
//
// File        : Float32Sqrt.v
// Tool        : Xilinx WebPack
//
//////////////////////////////////////////////////////////////////
//
// Description : IEEE 754 single precision synchronous floating point square root with radix 2 division.
//				 Obfuscated code. 
//////////////////////////////////////////////////////////////////

module Float32Sqrt(CLK, nRST, arg, loadArgs, status, busy, sqrt);
input CLK;              //Global clock. Rising edge active. 
input nRST;             //Global reset. Active low. 
input [31 : 0] arg;     //Input argument. Bit 31 - sign, Bits 30:23 exponent, Bits 22:0 mantissa. 
input loadArgs;         //Argument load strobe. Active high. 
output [2 : 0] status;	//Status output. Bit 2 - Not a Number, Bit 1 - Infinity, Bit 0 - Denormal. 
output busy;            //busy - high means performing calculations, low means result ready.
output [31 : 0] sqrt;   //Result. Valid if busy bit is low. Status bits 2:0 denote exceptions. 

wire[31:0]sqrt;wire[2:0]status;wire busy;wire IOOOO1,I0OOO1;reg IIOOO1;wire IlOOO1,I1OOO1;reg IOO0O1;wire I0O0O1,IIO0O1;reg [61:0]IlO0O1;wire[61:0]I1O0O1;wire IOOIO1;reg I0OIO1;wire IIOIO1,IlOIO1;reg [61:0]I1OIO1;reg [61:0]IOOlO1;wire I0OlO1;
reg [61:0]IIOlO1;wire[61:0]IlOlO1;wire I1OlO1;reg [2:0]IOO1O1;wire[2:0]I0O1O1;wire IIO1O1;reg IlO1O1;wire I1O1O1,IOOO01;reg [2:0]I0OO01;wire[2:0]IIOO01;wire IlOO01;reg I1OO01;wire IOO001,I0O001;reg [2:0]IIO001;
wire[2:0]IlO001;wire I1O001;reg IOOI01;wire I0OI01,IIOI01;reg [2:0]IlOI01;wire[2:0]I1OI01;wire IOOl01;reg I0Ol01;wire IIOl01,IlOl01;reg [2:0]I1Ol01;wire[2:0]IOO101;wire I0O101;reg IIO101;wire IlO101,I1O101;
reg [2:0]IOOOI1;wire[2:0]I0OOI1;wire IIOOI1;reg IlOOI1;wire I1OOI1,IOO0I1;reg [2:0]I0O0I1;wire[2:0]IIO0I1;wire IlO0I1;reg I1O0I1;wire IOOII1,I0OII1;reg [2:0]IIOII1;wire[2:0]IlOII1;wire I1OII1;reg IOOlI1;wire
I0OlI1,IIOlI1;reg [2:0]IlOlI1;reg [2:0]I1OlI1;wire IOO1I1;reg I0O1I1;wire IIO1I1,IlO1I1;reg [2:0]I1O1I1;wire[2:0]IOOOl1;wire I0OOl1;reg IIOOl1;wire IlOOl1,I1OOl1;reg [2:0]IOO0l1;wire[2:0]I0O0l1;wire IIO0l1
;reg IlO0l1;wire I1O0l1,IOOIl1;reg [2:0]I0OIl1;wire[2:0]IIOIl1;wire IlOIl1;reg I1OIl1;wire IOOll1,I0Oll1;reg [2:0]IIOll1;wire[2:0]IlOll1;wire I1Oll1;reg IOO1l1;wire I0O1l1,IIO1l1;reg [2:0]IlO1l1;wire[2:0]I1O1l1
;wire IOOO11;reg I0OO11;wire IIOO11,IlOO11;reg [2:0]I1OO11;wire[2:0]IOO011;wire I0O011;reg IIO011;wire IlO011,I1O011;reg [2:0]IOOI11;wire[2:0]I0OI11;wire IIOI11;reg IlOI11;wire I1OI11,IOOl11;reg [2:0]I0Ol11
;wire[2:0]IIOl11;wire IlOl11;reg I1Ol11;wire IOO111,I0O111;reg [2:0]IIO111;wire[2:0]IlO111;wire I1O111;reg IO0OO1;wire I00OO1,II0OO1;reg [2:0]Il0OO1;wire[2:0]I10OO1;wire IO00O1;reg I000O1;wire II00O1,Il00O1
;reg [2:0]I100O1;wire[2:0]IO0IO1;wire I00IO1;reg II0IO1;wire Il0IO1,I10IO1;reg [2:0]IO0lO1;wire[2:0]I00lO1;wire II0lO1;reg Il0lO1;wire I10lO1,IO01O1;reg [2:0]I001O1;wire[2:0]II01O1;wire Il01O1;reg I101O1;wire
IO0O01,I00O01;reg [2:0]II0O01;wire[2:0]Il0O01;wire I10O01;reg IO0001;wire I00001,II0001;reg [2:0]Il0001;wire[2:0]I10001;wire IO0I01;reg I00I01;wire II0I01,Il0I01;reg [2:0]I10I01;wire[2:0]IO0l01;wire I00l01
;reg II0l01;wire Il0l01,I10l01;reg [2:0]IO0101;wire[2:0]I00101;wire II0101;reg Il0101;wire I10101,IO0OI1;reg [2:0]I00OI1;wire[2:0]II0OI1;wire Il0OI1;reg I10OI1;wire IO00I1,I000I1;reg II00I1;wire Il00I1,I100I1
;reg [3:0]IO0II1;reg [3:0]I00II1;wire II0II1;reg Il0II1;wire I10II1,IO0lI1;reg [8:0]I00lI1;reg [8:0]II0lI1;wire Il0lI1;reg [28:0]I10lI1;wire[28:0]IO01I1;wire I001I1;reg [153:0]II01I1;wire[153:0]Il01I1;wire
I101I1;reg [7:0]IO0Ol1;wire[7:0]I00Ol1;wire II0Ol1;reg Il0Ol1;wire I10Ol1,IO00l1;reg [7:0]I000l1;wire[7:0]II00l1;wire Il00l1;reg [31:0]I100l1;wire[31:0]IO0Il1;wire I00Il1;reg [7:0]II0Il1;wire[7:0]Il0Il1;wire
I10Il1;reg IO0ll1;wire I00ll1,II0ll1;reg [23:0]Il0ll1;wire[23:0]I10ll1;wire IO01l1;reg I001l1;wire II01l1,Il01l1;reg [7:0]I101l1;reg [7:0]IO0O11;wire I00O11;reg [4:0]II0O11;wire[4:0]Il0O11;wire I10O11;reg [
4927:0]IO0011;wire[4927:0]I00011;wire II0011;reg [61:0]Il0011;reg [61:0]I10011;wire IO0I11;reg [29:0]I00I11;reg [29:0]II0I11;wire Il0I11;reg [29:0]I10I11;wire[29:0]IO0l11;wire I00l11;reg II0l11;wire Il0l11
,I10l11;reg IO0111;wire I00111,II0111;reg [8:0]Il0111;wire[8:0]I10111;wire IOIOO1;reg [4:0]I0IOO1;wire[4:0]IIIOO1;wire IlIOO1;reg I1IOO1;wire IOI0O1,I0I0O1;reg III0O1;wire IlI0O1,I1I0O1;reg [58:0]IOIIO1;wire
[58:0]I0IIO1;wire IIIIO1;reg [59:0]IlIIO1;wire[59:0]I1IIO1;wire IOIlO1;reg [29:0]I0IlO1;wire[29:0]IIIlO1;wire IlIlO1;reg [25:0]I1IlO1;wire[25:0]IOI1O1;wire I0I1O1;wire III1O1,IlI1O1,I1I1O1,IOIO01,I0IO01,IIIO01
,IlIO01,I1IO01,IOI001,I0I001,III001,IlI001,I1I001,IOII01,I0II01,IIII01,IlII01,I1II01,IOIl01,I0Il01,IIIl01,IlIl01,I1Il01,IOI101,I0I101,III101,IlI101,I1I101,IOIOI1,I0IOI1,IIIOI1,IlIOI1,I1IOI1,IOI0I1,I0I0I1
,III0I1,IlI0I1,I1I0I1,IOIII1,I0III1,IIIII1,IlIII1,I1III1,IOIlI1,I0IlI1,IIIlI1,IlIlI1,I1IlI1,IOI1I1,I0I1I1,III1I1,IlI1I1,I1I1I1,IOIOl1,I0IOl1,IIIOl1,IlIOl1,I1IOl1,IOI0l1,I0I0l1,III0l1,IlI0l1,I1I0l1,IOIIl1
,I0IIl1,IIIIl1,IlIIl1,I1IIl1,IOIll1,I0Ill1,IIIll1,IlIll1,I1Ill1,IOI1l1,I0I1l1,III1l1,IlI1l1,I1I1l1,IOIO11,I0IO11,IIIO11,IlIO11,I1IO11,IOI011,I0I011,III011,IlI011,I1I011,IOII11,I0II11,IIII11,IlII11,I1II11
,IOIl11,I0Il11,IIIl11,IlIl11,I1Il11,IOI111,I0I111,III111,IlI111,I1I111,IOlOO1,I0lOO1,IIlOO1,IllOO1,I1lOO1,IOl0O1,I0l0O1,IIl0O1,Ill0O1,I1l0O1,IOlIO1,I0lIO1,IIlIO1,IllIO1,I1lIO1,IOllO1,I0llO1,IIllO1,IlllO1
,I1llO1,IOl1O1,I0l1O1,IIl1O1,Ill1O1,I1l1O1,IOlO01,I0lO01,IIlO01,IllO01,I1lO01,IOl001,I0l001,IIl001,Ill001,I1l001,IOlI01,I0lI01,IIlI01,IllI01,I1lI01,IOll01,I0ll01,IIll01,Illl01,I1ll01,IOl101,I0l101,IIl101
,Ill101,I1l101,IOlOI1,I0lOI1,IIlOI1,IllOI1,I1lOI1,IOl0I1,I0l0I1,IIl0I1,Ill0I1,I1l0I1,IOlII1,I0lII1,IIlII1,IllII1,I1lII1,IOllI1,I0llI1,IIllI1,IlllI1,I1llI1,IOl1I1,I0l1I1,IIl1I1,Ill1I1,I1l1I1,IOlOl1,I0lOl1
,IIlOl1,IllOl1,I1lOl1,IOl0l1,I0l0l1,IIl0l1,Ill0l1,I1l0l1,IOlIl1,I0lIl1,IIlIl1,IllIl1,I1lIl1,IOlll1,I0lll1,IIlll1,Illll1,I1lll1,IOl1l1,I0l1l1,IIl1l1,Ill1l1,I1l1l1,IOlO11,I0lO11,IIlO11,IllO11,I1lO11,IOl011
,I0l011,IIl011,Ill011,I1l011,IOlI11,I0lI11,IIlI11,IllI11,I1lI11,IOll11,I0ll11,IIll11,Illl11,I1ll11,IOl111,I0l111,IIl111,Ill111,I1l111,IO1OO1,I01OO1,II1OO1,Il1OO1,I11OO1,IO10O1,I010O1,II10O1,Il10O1,I110O1
,IO1IO1,I01IO1,II1IO1,Il1IO1,I11IO1,IO1lO1,I01lO1,II1lO1,Il1lO1,I11lO1,IO11O1,I011O1,II11O1,Il11O1,I111O1,IO1O01,I01O01,II1O01,Il1O01,I11O01,IO1001,I01001,II1001,Il1001,I11001,IO1I01,I01I01,II1I01,Il1I01
,I11I01,IO1l01,I01l01,II1l01,Il1l01,I11l01,IO1101,I01101,II1101,Il1101,I11101,IO1OI1,I01OI1,II1OI1,Il1OI1,I11OI1,IO10I1,I010I1,II10I1,Il10I1,I110I1,IO1II1,I01II1,II1II1,Il1II1,I11II1,IO1lI1,I01lI1,II1lI1
,Il1lI1,I11lI1,IO11I1,I011I1,II11I1,Il11I1,I111I1,IO1Ol1,I01Ol1,II1Ol1,Il1Ol1,I11Ol1,IO10l1,I010l1,II10l1,Il10l1,I110l1,IO1Il1,I01Il1,II1Il1,Il1Il1,I11Il1,IO1ll1,I01ll1,II1ll1,Il1ll1,I11ll1,IO11l1,I011l1
,II11l1,Il11l1,I111l1,IO1O11,I01O11,II1O11,Il1O11,I11O11,IO1011,I01011,II1011,Il1011,I11011,IO1I11,I01I11,II1I11,Il1I11,I11I11,IO1l11,I01l11,II1l11,Il1l11,I11l11,IO1111,I01111,II1111,Il1111,I11111,IOOOOl
,I0OOOl,IIOOOl,IlOOOl,I1OOOl,IOO0Ol,I0O0Ol,IIO0Ol,IlO0Ol,I1O0Ol,IOOIOl,I0OIOl,IIOIOl,IlOIOl,I1OIOl,IOOlOl,I0OlOl,IIOlOl,IlOlOl,I1OlOl,IOO1Ol,I0O1Ol,IIO1Ol,IlO1Ol,I1O1Ol,IOOO0l,I0OO0l,IIOO0l,IlOO0l,I1OO0l
,IOO00l,I0O00l,IIO00l,IlO00l,I1O00l,IOOI0l,I0OI0l,IIOI0l,IlOI0l,I1OI0l,IOOl0l,I0Ol0l,IIOl0l,IlOl0l,I1Ol0l,IOO10l,I0O10l,IIO10l,IlO10l,I1O10l,IOOOIl,I0OOIl,IIOOIl,IlOOIl,I1OOIl,IOO0Il,I0O0Il,IIO0Il,IlO0Il
,I1O0Il,IOOIIl,I0OIIl,IIOIIl,IlOIIl,I1OIIl,IOOlIl,I0OlIl,IIOlIl,IlOlIl,I1OlIl,IOO1Il,I0O1Il,IIO1Il,IlO1Il,I1O1Il,IOOOll,I0OOll,IIOOll,IlOOll,I1OOll,IOO0ll,I0O0ll,IIO0ll,IlO0ll,I1O0ll;wire[61:0]IOOIll,
I0OIll,IIOIll;wire[29:0]IlOIll,I1OIll,IOOlll;wire[25:0]I0Olll,IIOlll;wire[8:0]IlOlll,I1Olll,IOO1ll,I0O1ll,IIO1ll;wire[7:0]IlO1ll,I1O1ll,IOOO1l,I0OO1l;wire IIOO1l,IlOO1l,I1OO1l,IOO01l,I0O01l,IIO01l,IlO01l
,I1O01l,IOOI1l,I0OI1l,IIOI1l,IlOI1l,I1OI1l,IOOl1l;wire[59:0]I0Ol1l,IIOl1l,IlOl1l,I1Ol1l;wire[58:0]IOO11l,I0O11l;wire[31:0]IIO11l,IlO11l,I1O11l,IO0OOl,I00OOl,II0OOl,Il0OOl,I10OOl,IO00Ol,I000Ol,II00Ol,Il00Ol
,I100Ol,IO0IOl,I00IOl,II0IOl,Il0IOl;wire[29:0]I10IOl,IO0lOl,I00lOl,II0lOl,Il0lOl,I10lOl,IO01Ol,I001Ol,II01Ol;wire[28:0]Il01Ol,I101Ol,IO0O0l,I00O0l,II0O0l;wire[27:0]Il0O0l;wire[25:0]I10O0l;wire[8:0]IO000l
,I0000l,II000l,Il000l;wire[4:0]I1000l;wire[3:0]IO0I0l;wire I00I0l,II0I0l,Il0I0l,I10I0l,IO0l0l,I00l0l,II0l0l,Il0l0l,I10l0l,IO010l,I0010l,II010l,Il010l,I1010l,IO0OIl,I00OIl,II0OIl,Il0OIl,I10OIl,IO00Il,I000Il
,II00Il,Il00Il,I100Il,IO0IIl,I00IIl,II0IIl,Il0IIl,I10IIl,IO0lIl,I00lIl,II0lIl,Il0lIl,I10lIl,IO01Il,I001Il,II01Il,Il01Il,I101Il,IO0Oll,I00Oll,II0Oll,Il0Oll,I10Oll,IO00ll,I000ll,II00ll,Il00ll,I100ll,IO0Ill
,I00Ill,II0Ill,Il0Ill,I10Ill,IO0lll,I00lll,II0lll,Il0lll,I10lll,IO01ll,I001ll,II01ll,Il01ll,I101ll,IO0O1l,I00O1l,II0O1l,Il0O1l,I10O1l,IO001l,I0001l,II001l,Il001l,I1001l,IO0I1l,I00I1l,II0I1l,Il0I1l,I10I1l
,IO0l1l,I00l1l,II0l1l,Il0l1l,I10l1l;assign I1lI11=1'd1;assign IlO0ll=loadArgs;assign status={I001l1,Il0Ol1,I0OIO1};assign busy=IOO0O1;assign sqrt={I1IOO1,I00lI1[7:0],I1IlO1[25:3]};assign IOll11=1'd1;assign
I1O0ll=1'd1;assign I1I1O1=Il0111[0];assign Illl11=I1I1O1;assign IOIO01=Il0111[1];assign I1ll11=IOIO01;assign IOI0l1=I001ll&& IO01ll&& I10lll&& IO0II1== 4'd2&& I10I0l;assign I11101=IOI0l1;assign I0I0l1
=II0Ill&& I00Ill&& IO0II1== 4'd10&& I10I0l;assign IO1OI1=I0I0l1;assign IOII01=IO1OI1|| I11101;assign I11OO1=IOII01;assign III0l1=I001ll&& IO01ll&& I10lll&& IO0II1== 4'd2&& Il0O1l;assign I01OI1=III0l1;
assign IlI0l1=II0Ill&& I00Ill&& IO0II1== 4'd10&& Il0O1l;assign II1OI1=IlI0l1;assign I0II01=II1OI1|| I01OI1;assign IO10O1=I0II01;assign I1Il11=I001ll&& IO01ll&& I10lll&& IO0II1== 4'd2&& !I10O1l;assign Il1Il1
=I1Il11;assign IOI111=II0Ill&& I00Ill&& IO0II1== 4'd10&& !I10O1l;assign I11Il1=IOI111;assign IIIII1=I11Il1|| Il1Il1;assign I01001=IIIII1;assign I1I0l1=IO0lIl&& IO0II1== 4'd2&& I10O1l&& II00Il;assign Il1OI1
=I1I0l1;assign IOIIl1=I10IIl&& I00IIl&& II0IIl&& Il0IIl&& IO0II1== 4'd5&& I1001l;assign I11OI1=IOIIl1;assign I0IIl1=I10IIl&& I00IIl&& II0IIl&& Il0IIl&& II0Ill&& I00Ill&& IO0II1== 4'd10&& I10O1l&& II00Il
;assign IO10I1=I0IIl1;assign IIII01=IO10I1|| I11OI1|| Il1OI1;assign I010O1=IIII01;assign IOIll1=I0Il01;assign I110I1=I0Il01;assign I0Il01=IIO001== 3'd1&& (IIII01|| IOOI01);assign IO1IO1=I0Il01;assign IlIIl1
=I1II01;assign II10I1=I1II01;assign I1II01=IOO1O1== 3'd1&& (IIII01|| IlO1O1);assign Il10O1=I1II01;assign IIIIl1=IlII01;assign I010I1=IlII01;assign I1IIl1=IOIl01;assign Il10I1=IOIl01;assign IOIl01=I0OO01
== 3'd1&& (IIII01|| I1OO01);assign I110O1=IOIl01;assign IlII01=IlOI01== 3'd1&& (IIII01|| I0Ol01);assign II10O1=IlII01;assign I0Ill1=Il0lIl&& I00lIl&& II0lIl&& I001ll&& IO01ll&& I10lll&& IO0II1== 4'd2&&
I10O1l&& Il00Il;assign IO1II1=I0Ill1;assign IIIll1=I10lIl&& IO0II1== 4'd5&& !I1001l;assign I01II1=IIIll1;assign IlIll1=Il0lIl&& I00lIl&& II0lIl&& II0Ill&& I00Ill&& IO0II1== 4'd10&& I10O1l&& Il00Il;assign
II1II1=IlIll1;assign IIIl01=II1II1|| I01II1|| IO1II1;assign I01IO1=IIIl01;assign I0I1l1=IOI101;assign IO1lI1=IOI101;assign IOI101=IOOOI1== 3'd1&& (IIIl01|| IlOOI1);assign I11IO1=IOI101;assign IOI1l1=I1Il01
;assign I11II1=I1Il01;assign I1Il01=I1Ol01== 3'd1&& (IIIl01|| IIO101);assign Il1IO1=I1Il01;assign III1l1=I101Il&& IO0II1== 4'd7&& II0O1l;assign I01lI1=III1l1;assign I1Ill1=IlIl01;assign Il1II1=IlIl01;
assign IlIl01=I0O0I1== 3'd1&& (IIIl01|| I1O0I1);assign II1IO1=IlIl01;assign IlI1l1=Il01Il&& IO01Il&& I001Il&& II01Il&& IO0II1== 4'd8&& II0O1l;assign II1lI1=IlI1l1;assign I0I101=II1lI1|| I01lI1;assign IO1lO1
=I0I101;assign IlIO11=I0IOI1;assign II11I1=I0IOI1;assign I0IOI1=I1O1I1== 3'd1&& (I0I101|| IIOOl1);assign IO11O1=I0IOI1;assign IOIO11=IlI101;assign I11lI1=IlI101;assign I0IO11=I1I101;assign IO11I1=I1I101
;assign I1I101=IlOlI1== 3'd1&& (I0I101|| I0O1I1)&& ~II0lOl[29];assign Il1lO1=I1I101;assign IIIO11=IOIOI1;assign I011I1=IOIOI1;assign IOIOI1=IlOlI1== 3'd1&& (I0I101|| I0O1I1)&& !(~II0lOl[29]);assign I11lO1
=IOIOI1;assign IlI101=IIOII1== 3'd1&& (I0I101|| IOOlI1);assign II1lO1=IlI101;assign I1I1l1=III101;assign Il1lI1=III101;assign III101=IOO0l1== 3'd1&& (I0I101|| IlO0l1);assign I01lO1=III101;assign I1IO11
=I10Ill&& IO0Oll&& II0Oll&& Il0Oll&& I10Oll&& II00ll&& IO0II1== 4'd2&& I10O1l&& I10I11== 30'd0;assign Il11I1=I1IO11;assign I0I011=I10Ill&& IO0Oll&& I00Oll&& IO0II1== 4'd4;assign IO1Ol1=I0I011;assign IOI011
=I10Ill&& IO0Oll&& I00Oll&& IO0II1== 4'd3;assign I111I1=IOI011;assign III011=I10Ill&& IO0Oll&& II0Oll&& Il0Oll&& I10Oll&& IO00ll&& IO0II1== 4'd7&& !II0O1l;assign I01Ol1=III011;assign IlI011=Il0Ill&& IO0II1
== 4'd8&& !II0O1l;assign II1Ol1=IlI011;assign I1I011=I10Ill&& IO0Oll&& I00Oll&& IO0II1== 4'd10&& I10O1l&& I10I11== 30'd0;assign Il1Ol1=I1I011;assign IIIOI1=Il1Ol1|| II1Ol1|| I01Ol1|| IO1Ol1|| I111I1||
Il11I1;assign I011O1=IIIOI1;assign IlIl11=I0III1;assign II1Il1=I0III1;assign I0III1=Il0OO1== 3'd1&& (IIIOI1|| I000O1);assign IO1001=I0III1;assign IIIl11=IOIII1;assign I01Il1=IOIII1;assign IOIII1=IIO111
== 3'd1&& (IIIOI1|| IO0OO1);assign I11O01=IOIII1;assign IOIl11=IlI0I1;assign I110l1=IlI0I1;assign IlI0I1=IOOI11== 3'd1&& (IIIOI1|| IlOI11);assign II1O01=IlI0I1;assign I1II11=III0I1;assign Il10l1=III0I1
;assign III0I1=I1OO11== 3'd1&& (IIIOI1|| IIO011);assign I01O01=III0I1;assign IlII11=I0I0I1;assign II10l1=I0I0I1;assign I0I0I1=IlO1l1== 3'd1&& (IIIOI1|| I0OO11);assign IO1O01=I0I0I1;assign IIII11=IOI0I1
;assign I010l1=IOI0I1;assign IOI0I1=IIOll1== 3'd1&& (IIIOI1|| IOO1l1);assign I111O1=IOI0I1;assign I0II11=I1IOI1;assign IO10l1=I1IOI1;assign I1IOI1=I0OIl1== 3'd1&& (IIIOI1|| I1OIl1);assign Il11O1=I1IOI1
;assign IIlI11=(IO0II1== 4'd12|| IO0II1== 4'd1&& !Il0II1)&& !II00I1&& Il0111[3];assign I0O0ll=IIlI11;assign IllI11=Il0111[5];assign IIO0ll=IllI11;assign IOII11=IlIOI1;assign I11Ol1=IlIOI1;assign I0Il11
=I1I0I1;assign IO1Il1=I1I0I1;assign I1I0I1=I0Ol11== 3'd1&& (IIIOI1|| I1Ol11);assign Il1O01=I1I0I1;assign IlIOI1=I100O1== 3'd1&& (IIIOI1|| II0IO1);assign II11O1=IlIOI1;assign Ill011=Il0111[6];assign IIOOll
=Ill011;assign IOlI11=Il0111[7];assign I1OOll=IOlI11;assign IlI1O1=Il0111[8];assign IIll11=IlI1O1;assign I0I111=(IO0II1== 4'd12|| IO0II1== 4'd1&& !Il0II1)&& II00I1;assign IO1ll1=I0I111;assign III1I1=IIIO01
;assign I01l01=IIIO01;assign IIIO01=Il01ll&& IO0II1== 4'd1&& (I0I111|| Il0II1);assign I0l111=IIIO01;assign I1IOl1=I1I001;assign Il1101=I1I001;assign I1I001=IO0101== 3'd1&& (IIIO01|| Il0101);assign Il1OO1
=I1I001;assign IlIOl1=IlI001;assign II1101=IlI001;assign IlI001=I10I01== 3'd1&& (IIIO01|| II0l01);assign II1OO1=IlI001;assign IIIOl1=III001;assign I01101=III001;assign III001=Il0001== 3'd1&& (IIIO01||
I00I01);assign I01OO1=III001;assign I0IOl1=I0I001;assign IO1101=I0I001;assign I0I001=II0O01== 3'd1&& (IIIO01|| IO0001);assign IO1OO1=I0I001;assign IOIOl1=IOI001;assign I11l01=IOI001;assign IOI001=I001O1
== 3'd1&& (IIIO01|| I101O1);assign I1l111=IOI001;assign I1I1I1=I1IO01;assign Il1l01=I1IO01;assign I1IO01=IO0lO1== 3'd1&& (IIIO01|| Il0lO1);assign Ill111=I1IO01;assign IlI1I1=IlIO01;assign II1l01=IlIO01
;assign IlIO01=I00OI1== 3'd1&& (IIIO01|| I10OI1);assign IIl111=IlIO01;assign I1l011=Il0111[2];assign IlOOll=I1l011;assign I0lI11=1'd1;assign IOO0ll=1'd1;assign III1O1=loadArgs&& !IOO0O1;assign I0ll11=
III1O1;assign IlIII1=1'b0;assign II1001=1'b0;assign IIIlI1=1'b0;assign I01I01=1'b0;assign I1III1=1'b0;assign Il1001=1'b0;assign IOIlI1=1'b0;assign I11001=1'b0;assign I0IlI1=1'b0;assign IO1I01=1'b0;assign
IlIlI1=1'b0;assign II1I01=1'b0;assign I1IlI1=1'b0;assign Il1I01=1'b0;assign IOI1I1=IO0II1== 4'd12;assign I11I01=IOI1I1;assign I0I1I1=IO0II1== 4'd1&& !I0I111&& !Il0II1;assign IO1l01=I0I1I1;assign I0IO01
=IO1l01|| I11I01;assign IOl111=I0IO01;assign IIllI1=Il0OO1== 3'd2;assign I0OI0l=IIllI1;assign IlllI1=Il0OO1== 3'd1&& !IIIOI1&& !I000O1;assign IIOI0l=IlllI1;assign IOlOI1=IIOI0l|| I0OI0l;assign I1OlOl=
IOlOI1;assign I0lOl1=I0III1|| IIIOI1;assign IOO10l=I0lOl1;assign IOllI1=IIO111== 3'd2;assign I1O00l=IOllI1;assign I0llI1=IIO111== 3'd1&& !IIIOI1&& !IO0OO1;assign IOOI0l=I0llI1;assign I1l101=IOOI0l|| I1O00l
;assign IlOlOl=I1l101;assign IOlOl1=IOIII1|| IIIOI1;assign I1Ol0l=IOlOl1;assign IllII1=I0Ol11== 3'd2;assign IIO00l=IllII1;assign I1lII1=I0Ol11== 3'd1&& !IIIOI1&& !I1Ol11;assign IlO00l=I1lII1;assign Ill101
=IlO00l|| IIO00l;assign IIOlOl=Ill101;assign I1l1I1=I1I0I1|| IIIOI1;assign IlOl0l=I1l1I1;assign I0lII1=IOOI11== 3'd2;assign IOO00l=I0lII1;assign IIlII1=IOOI11== 3'd1&& !IIIOI1&& !IlOI11;assign I0O00l=
IIlII1;assign IIl101=I0O00l|| IOO00l;assign I0OlOl=IIl101;assign Ill1I1=IlI0I1|| IIIOI1;assign IIOl0l=Ill1I1;assign I1l0I1=I1OO11== 3'd2;assign IlOO0l=I1l0I1;assign IOlII1=I1OO11== 3'd1&& !IIIOI1&& !IIO011
;assign I1OO0l=IOlII1;assign I0l101=I1OO0l|| IlOO0l;assign IOOlOl=I0l101;assign IIl1I1=III0I1|| IIIOI1;assign I0Ol0l=IIl1I1;assign IIl0I1=IlO1l1== 3'd2;assign I0OO0l=IIl0I1;assign Ill0I1=IlO1l1== 3'd1
&& !IIIOI1&& !I0OO11;assign IIOO0l=Ill0I1;assign IOl101=IIOO0l|| I0OO0l;assign I1OIOl=IOl101;assign I0l1I1=I0I0I1|| IIIOI1;assign IOOl0l=I0l1I1;assign IOl0I1=IIOll1== 3'd2;assign I1O1Ol=IOl0I1;assign I0l0I1
=IIOll1== 3'd1&& !IIIOI1&& !IOO1l1;assign IOOO0l=I0l0I1;assign I1ll01=IOOO0l|| I1O1Ol;assign IlOIOl=I1ll01;assign IOl1I1=IOI0I1|| IIIOI1;assign I1OI0l=IOl1I1;assign IllOI1=I0OIl1== 3'd2;assign IIO1Ol=
IllOI1;assign I1lOI1=I0OIl1== 3'd1&& !IIIOI1&& !I1OIl1;assign IlO1Ol=I1lOI1;assign Illl01=IlO1Ol|| IIO1Ol;assign IIOIOl=Illl01;assign I1llI1=I1IOI1|| IIIOI1;assign IlOI0l=I1llI1;assign I0lOI1=I100O1==
3'd2;assign IOO1Ol=I0lOI1;assign IIlOI1=I100O1== 3'd1&& !IIIOI1&& !II0IO1;assign I0O1Ol=IIlOI1;assign IIll01=I0O1Ol|| IOO1Ol;assign I0OIOl=IIll01;assign IIlOl1=IlIOI1|| IIIOI1;assign I0O10l=IIlOl1;assign
I0lI01=I1O1I1== 3'd2;assign IOO0Ol=I0lI01;assign IIlI01=I1O1I1== 3'd1&& !I0I101&& !IIOOl1;assign I0O0Ol=IIlI01;assign IllO01=I0O0Ol|| IOO0Ol;assign II1111=IllO01;assign IOll01=I0IOI1|| I0I101;assign I1O0Ol
=IOll01;assign Ill001=IlOlI1== 3'd2;assign IIOOOl=Ill001;assign I1l001=IlOlI1== 3'd3;assign IlOOOl=I1l001;assign IOlI01=IlOlI1== 3'd1&& !I0I101&& !I0O1I1;assign I1OOOl=IOlI01;assign IIlO01=I1OOOl|| IlOOOl
|| IIOOOl;assign I01111=IIlO01;assign I1lI01=IOOOO1|| I0I101;assign IlO0Ol=I1lI01;assign I0l001=IIOII1== 3'd2;assign IOOOOl=I0l001;assign IIl001=IIOII1== 3'd1&& !I0I101&& !IOOlI1;assign I0OOOl=IIl001;
assign I0lO01=I0OOOl|| IOOOOl;assign IO1111=I0lO01;assign IllI01=IlI101|| I0I101;assign IIO0Ol=IllI01;assign I1lO01=IOO0l1== 3'd2;assign Il1111=I1lO01;assign IOl001=IOO0l1== 3'd1&& !I0I101&& !IlO0l1;assign
I11111=IOl001;assign IOlO01=I11111|| Il1111;assign I11l11=IOlO01;assign I0ll01=III101|| I0I101;assign IOOIOl=I0ll01;assign IOl1O1=IOOOI1== 3'd2;assign I11I11=IOl1O1;assign I0l1O1=IOOOI1== 3'd1&& !IIIl01
&& !IlOOI1;assign IO1l11=I0l1O1;assign IOllO1=IO1l11|| I11I11;assign I11011=IOllO1;assign Ill1O1=IOI101|| IIIl01;assign II1l11=Ill1O1;assign IlllO1=I1Ol01== 3'd2;assign II1I11=IlllO1;assign I1llO1=I1Ol01
== 3'd1&& !IIIl01&& !IIO101;assign Il1I11=I1llO1;assign I1lIO1=Il1I11|| II1I11;assign Il1011=I1lIO1;assign IIl1O1=I1Il01|| IIIl01;assign I01l11=IIl1O1;assign I0llO1=I0O0I1== 3'd2;assign IO1I11=I0llO1;
assign IIllO1=I0O0I1== 3'd1&& !IIIl01&& !I1O0I1;assign I01I11=IIllO1;assign IllIO1=I01I11|| IO1I11;assign II1011=IllIO1;assign I1l1O1=IlIl01|| IIIl01;assign Il1l11=I1l1O1;assign IIl0O1=IIO001== 3'd2;assign
I01O11=IIl0O1;assign Ill0O1=IIO001== 3'd1&& !IIII01&& !IOOI01;assign II1O11=Ill0O1;assign IOlOO1=II1O11|| I01O11;assign I11ll1=IOlOO1;assign I0lIO1=I0Il01|| IIII01;assign IO1011=I0lIO1;assign IOl0O1=I0OO01
== 3'd2;assign I111l1=IOl0O1;assign I0l0O1=I0OO01== 3'd1&& !IIII01&& !I1OO01;assign IO1O11=I0l0O1;assign I1I111=IO1O11|| I111l1;assign Il1ll1=I1I111;assign IOlIO1=IOIl01|| IIII01;assign I11O11=IOlIO1;
assign IllOO1=IOO1O1== 3'd2;assign II11l1=IllOO1;assign I1lOO1=IOO1O1== 3'd1&& !IIII01&& !IlO1O1;assign Il11l1=I1lOO1;assign IlI111=Il11l1|| II11l1;assign II1ll1=IlI111;assign I1l0O1=I1II01|| IIII01;assign
Il1O11=I1l0O1;assign I0lOO1=IlOI01== 3'd2;assign IO11l1=I0lOO1;assign IIlOO1=IlOI01== 3'd1&& !IIII01&& !I0Ol01;assign I011l1=IIlOO1;assign III111=I011l1|| IO11l1;assign I01ll1=III111;assign IIlIO1=IlII01
|| IIII01;assign I01011=IIlIO1;assign IIl1l1=IO0101== 3'd2;assign I0OlIl=IIl1l1;assign Ill1l1=IO0101== 3'd1&& !IIIO01&& !Il0101;assign IIOlIl=Ill1l1;assign I1l0l1=IIOlIl|| I0OlIl;assign IlOOIl=I1l0l1;
assign I1lO11=I1I001|| IIIO01;assign IlO1Il=I1lO11;assign IOl1l1=I10I01== 3'd2;assign I1OIIl=IOl1l1;assign I0l1l1=I10I01== 3'd1&& !IIIO01&& !II0l01;assign IOOlIl=I0l1l1;assign Ill0l1=IOOlIl|| I1OIIl;assign
IIOOIl=Ill0l1;assign IllO11=IlI001|| IIIO01;assign IIO1Il=IllO11;assign Illll1=Il0001== 3'd2;assign IIOIIl=Illll1;assign I1lll1=Il0001== 3'd1&& !IIIO01&& !I00I01;assign IlOIIl=I1lll1;assign IIl0l1=IlOIIl
|| IIOIIl;assign I0OOIl=IIl0l1;assign IIlO11=III001|| IIIO01;assign I0O1Il=IIlO11;assign I0lll1=II0O01== 3'd2;assign IOOIIl=I0lll1;assign IIlll1=II0O01== 3'd1&& !IIIO01&& !IO0001;assign I0OIIl=IIlll1;
assign I0l0l1=I0OIIl|| IOOIIl;assign IOOOIl=I0l0l1;assign I0lO11=I0I001|| IIIO01;assign IOO1Il=I0lO11;assign I1lIl1=I001O1== 3'd2;assign IlO0Il=I1lIl1;assign IOlll1=I001O1== 3'd1&& !IIIO01&& !I101O1;assign
I1O0Il=IOlll1;assign IOl0l1=I1O0Il|| IlO0Il;assign I1O10l=IOl0l1;assign IOlO11=IOI001|| IIIO01;assign I1OlIl=IOlO11;assign IIlIl1=IO0lO1== 3'd2;assign I0O0Il=IIlIl1;assign IllIl1=IO0lO1== 3'd1&& !IIIO01
&& !Il0lO1;assign IIO0Il=IllIl1;assign I1lOl1=IIO0Il|| I0O0Il;assign IlO10l=I1lOl1;assign I1l1l1=I1IO01|| IIIO01;assign IlOlIl=I1l1l1;assign IOlIl1=I00OI1== 3'd2;assign I1OOIl=IOlIl1;assign I0lIl1=I00OI1
== 3'd1&& !IIIO01&& !I10OI1;assign IOO0Il=I0lIl1;assign IllOl1=IOO0Il|| I1OOIl;assign IIO10l=IllOl1;assign IOl011=IlIO01|| IIIO01;assign I1O1Il=IOl011;assign I0l011=1'd1;assign IOOOll=1'd1;assign IIl011
=I0OOO1|| I0I111;assign I0OOll=IIl011;assign IIOO1l=Il0111[6]&& I101ll&& I00O1l;assign I1OO1l=IO10l1|| II1101;assign IOO01l=Il1lI1|| Il10I1;assign IIO01l=Il0111[7]&& I00I0l&& I0IlO1[25:3]== 23'd8388607
;assign I0O01l=Il0111[6]&& (I101ll&& !I00O1l|| !I101ll&& IO0O1l);assign IlO01l=Il0111[6]&& !I101ll&& !IO0O1l;assign IOOI1l=I010l1|| II1l01;assign I0OI1l=IO1Il1|| I01101;assign IIOI1l=I011I1|| I010I1;assign
IlOI1l=I110l1|| IO1101;assign I1OI1l=Il0111[8]&& (I001l1|| Il0Ol1);assign IOOl1l=Il0111[8]&& (I001l1|| Il0Ol1|| IIOOO1);assign IlOO1l=!Il001l&& Il0I0l;assign I0OIll={I1OIO1[60:0],1'd0};assign IOOIll={
I10lI1,33'b0};assign IlOlll=I101ll ? 9'd384:I0000l;assign I1Olll=I00lI1+9'd1;assign IOO1ll={II000l[8],II000l[8:1]};assign I0O1ll=(I001l1|| Il0Ol1)? 9'b111111111:(IIOOO1 ? 9'd0:{I00lI1[8],~I00lI1[7],I00lI1
[6:0]});assign IIO1ll=I00lI1-9'd1;assign IlO1ll=IO0Ol1+8'd1;assign I1O01l=!Il001l&& II0I0l;assign I1O1ll=I000l1+8'd1;assign IOOO1l=I101l1+8'd1;assign I0OO1l=I101l1-8'd1;assign IIOIll={Il0011[60:0],~II0lOl
[29]};assign IlOIll={1'd0,I00I11[29:1]};assign I1OIll={1'b0,I101Ol[28],Il01Ol[27:0]};assign IOOlll=I101ll ? (IO000l[8]? I10lOl:IO01Ol):(((II0O11^ 5'h10)<= 5'd16)? II01Ol:I001Ol);assign I0Olll=I001l1 ? 26'd8
:26'd0;assign IIOlll=I00I0l ? ((I0IlO1[25:3]== 23'd8388607)? 26'd0:I10O0l):I0IlO1[25:0];assign I0OOO1=Il1Ol1|| II1Ol1|| I01Ol1|| IO1Ol1|| I111I1|| Il11I1|| II1lI1|| I01lI1|| II1II1|| I01II1|| IO1II1|| IO10I1
|| I11OI1|| Il1OI1|| I01l01|| I11Il1|| Il1Il1|| II1OI1|| I01OI1|| IO1OI1|| I11101;assign IOOOO1=I011I1|| IO11I1;assign IlOOO1=IIOO1l|| IlOO1l;assign I1OOO1=Il0111[6]&& I101ll&& I00O1l|| Il0111[0];assign
I0O0O1=I0ll11;assign IIO0O1=Il0111[8]|| I0ll11;assign I1O0O1=62'h0;assign IOOIO1=1'b0;assign IIOIO1=I101ll&& !I00O1l;assign IlOIO1=Ill011;always @(I1OO1l or IOOIll or IOO01l or I0OIll or Il1II1 or IIOlO1)begin
case (1'b1)I1OO1l:IOOlO1=IOOIll;IOO01l:IOOlO1=I0OIll;Il1II1:IOOlO1=IIOlO1;default :IOOlO1=62'h2aaaaaaaaaaaaaaa;endcase end assign I0OlO1=IO10l1|| II1101|| Il1lI1|| Il10I1|| Il1II1;assign IlOlO1=I1OIO1
;assign I1OlO1=I1II01;assign I0O1O1=IlI111 ? 3'd1:3'd2;assign IIO1O1=Il11l1|| II11l1|| II10I1;assign I1O1O1=!I1II01;assign IOOO01=I1l0O1;assign IIOO01=I1I111 ? 3'd1:3'd2;assign IlOO01=IO1O11|| I111l1|| Il10I1
;assign IOO001=!IOIl01;assign I0O001=IOlIO1;assign IlO001=IOlOO1 ? 3'd1:3'd2;assign I1O001=II1O11|| I01O11|| I110I1;assign I0OI01=!I0Il01;assign IIOI01=I0lIO1;assign I1OI01=III111 ? 3'd1:3'd2;assign IOOl01
=I011l1|| IO11l1|| I010I1;assign IIOl01=!IlII01;assign IlOl01=IIlIO1;assign IOO101=I1lIO1 ? 3'd1:3'd2;assign I0O101=Il1I11|| II1I11|| I11II1;assign IlO101=!I1Il01;assign I1O101=IIl1O1;assign I0OOI1=IOllO1
? 3'd1:3'd2;assign IIOOI1=IO1l11|| I11I11|| IO1lI1;assign I1OOI1=!IOI101;assign IOO0I1=Ill1O1;assign IIO0I1=IllIO1 ? 3'd1:3'd2;assign IlO0I1=I01I11|| IO1I11|| Il1II1;assign IOOII1=!IlIl01;assign I0OII1
=I1l1O1;assign IlOII1=I0lO01 ? 3'd1:3'd2;assign I1OII1=I0OOOl|| IOOOOl|| I11lI1;assign I0OlI1=!IlI101;assign IIOlI1=IllI01;always @(IIlO01 or IO11I1 or I011I1)begin case (1'b1)IIlO01:I1OlI1=3'd1;IO11I1:I1OlI1
=3'd2;I011I1:I1OlI1=3'd3;default :I1OlI1=3'b010;endcase end assign IOO1I1=I1OOOl|| IlOOOl|| IIOOOl|| IO11I1|| I011I1;assign IIO1I1=!IOOOO1;assign IlO1I1=I1lI01;assign IOOOl1=IllO01 ? 3'd1:3'd2;assign I0OOl1
=I0O0Ol|| IOO0Ol|| II11I1;assign IlOOl1=!I0IOI1;assign I1OOl1=IOll01;assign I0O0l1=IOlO01 ? 3'd1:3'd2;assign IIO0l1=I11111|| Il1111|| Il1lI1;assign I1O0l1=!III101;assign IOOIl1=I0ll01;assign IIOIl1=Illl01
? 3'd1:3'd2;assign IlOIl1=IlO1Ol|| IIO1Ol|| IO10l1;assign IOOll1=!I1IOI1;assign I0Oll1=I1llI1;assign IlOll1=I1ll01 ? 3'd1:3'd2;assign I1Oll1=IOOO0l|| I1O1Ol|| I010l1;assign I0O1l1=!IOI0I1;assign IIO1l1
=IOl1I1;assign I1O1l1=IOl101 ? 3'd1:3'd2;assign IOOO11=IIOO0l|| I0OO0l|| II10l1;assign IIOO11=!I0I0I1;assign IlOO11=I0l1I1;assign IOO011=I0l101 ? 3'd1:3'd2;assign I0O011=I1OO0l|| IlOO0l|| Il10l1;assign IlO011
=!III0I1;assign I1O011=IIl1I1;assign I0OI11=IIl101 ? 3'd1:3'd2;assign IIOI11=I0O00l|| IOO00l|| I110l1;assign I1OI11=!IlI0I1;assign IOOl11=Ill1I1;assign IIOl11=Ill101 ? 3'd1:3'd2;assign IlOl11=IlO00l|| IIO00l
|| IO1Il1;assign IOO111=!I1I0I1;assign I0O111=I1l1I1;assign IlO111=I1l101 ? 3'd1:3'd2;assign I1O111=IOOI0l|| I1O00l|| I01Il1;assign I00OO1=!IOIII1;assign II0OO1=IOlOl1;assign I10OO1=IOlOI1 ? 3'd1:3'd2;assign
IO00O1=IIOI0l|| I0OI0l|| II1Il1;assign II00O1=!I0III1;assign Il00O1=I0lOl1;assign IO0IO1=IIll01 ? 3'd1:3'd2;assign I00IO1=I0O1Ol|| IOO1Ol|| I11Ol1;assign Il0IO1=!IlIOI1;assign I10IO1=IIlOl1;assign I00lO1
=I1lOl1 ? 3'd1:3'd2;assign II0lO1=IIO0Il|| I0O0Il|| Il1l01;assign I10lO1=!I1IO01;assign IO01O1=I1l1l1;assign II01O1=IOl0l1 ? 3'd1:3'd2;assign Il01O1=I1O0Il|| IlO0Il|| I11l01;assign IO0O01=!IOI001;assign
I00O01=IOlO11;assign Il0O01=I0l0l1 ? 3'd1:3'd2;assign I10O01=I0OIIl|| IOOIIl|| IO1101;assign I00001=!I0I001;assign II0001=I0lO11;assign I10001=IIl0l1 ? 3'd1:3'd2;assign IO0I01=IlOIIl|| IIOIIl|| I01101;assign
II0I01=!III001;assign Il0I01=IIlO11;assign IO0l01=Ill0l1 ? 3'd1:3'd2;assign I00l01=IOOlIl|| I1OIIl|| II1101;assign Il0l01=!IlI001;assign I10l01=IllO11;assign I00101=I1l0l1 ? 3'd1:3'd2;assign II0101=IIOlIl
|| I0OlIl|| Il1101;assign I10101=!I1I001;assign IO0OI1=I1lO11;assign II0OI1=IllOl1 ? 3'd1:3'd2;assign Il0OI1=IOO0Il|| I1OOIl|| II1l01;assign IO00I1=!IlIO01;assign I000I1=IOl011;assign Il00I1=IIlI11;assign
I100I1=1'd1;always @(I0IO01 or I01l01 or IOII01 or I0II01 or IIII01 or IIIl01 or I0I101 or IIIOI1 or IIIII1)begin case (1'b1)I0IO01:I00II1=4'd1;I01l01:I00II1=4'd2;IOII01:I00II1=4'd3;I0II01:I00II1=4'd4;IIII01:
I00II1=4'd5;IIIl01:I00II1=4'd7;I0I101:I00II1=4'd8;IIIOI1:I00II1=4'd10;IIIII1:I00II1=4'd12;default :I00II1=4'b1010;endcase end assign II0II1=IO1l01|| I11I01|| I01l01|| IO1OI1|| I11101|| II1OI1|| I01OI1
|| IO10I1|| I11OI1|| Il1OI1|| II1II1|| I01II1|| IO1II1|| II1lI1|| I01lI1|| Il1Ol1|| II1Ol1|| I01Ol1|| IO1Ol1|| I111I1|| Il11I1|| I11Il1|| Il1Il1;assign I10II1=!I0OOO1;assign IO0lI1=IIl011;always @(I0O01l
or IlOlll or IIO01l or I1Olll or Il0111 or IOO1ll or I0O1ll or IIO1ll)begin case (1'b1)I0O01l:II0lI1=IlOlll;IIO01l:II0lI1=I1Olll;Il0111[2]:II0lI1=IOO1ll;Il0111[8]:II0lI1=I0O1ll;Il0111[5]:II0lI1=IIO1ll;default
:II0lI1=9'b010101010;endcase end assign Il0lI1=I0O01l|| Il0111[7]&& I00I0l&& I0IlO1[25:3]== 23'd8388607|| Il0111[2]|| Il0111[8]|| Il0111[5];assign IO01I1=II000l[0]? II0O0l:IO0O0l;assign I001I1=I1l011;
assign Il01I1=154'h0;assign I101I1=1'b0;assign I00Ol1=II11I1 ? IlO1ll:8'd0;assign II0Ol1=II11I1|| II10l1|| Il1l01;assign I10Ol1=IlO01l|| I1O01l;assign IO00l1=Il0111[6]&& !I101ll&& !IO0O1l|| Il0111[0];assign
II00l1=Il10l1 ? I1O1ll:8'd0;assign Il00l1=Il10l1|| I11l01;assign IO0Il1=arg;assign I00Il1=III1O1;assign Il0Il1=I0001l ? 8'h81:I100l1[30:23]-8'd128;assign I10Il1=IOIO01;assign I00ll1=I10l1l;assign II0ll1
=IOIO01;assign I10ll1={I10l1l,I100l1[22:0]};assign IO01l1=IOIO01;assign II01l1=Il001l;assign Il01l1=I1I1O1;always @(IO1lI1 or IOOO1l or I110I1 or I0OO1l or IOOI1l)begin case (1'b1)IO1lI1:IO0O11=IOOO1l;I110I1
:IO0O11=I0OO1l;IOOI1l:IO0O11=8'd62;default :IO0O11=8'b10101010;endcase end assign I00O11=IO1lI1|| I110I1|| I010l1|| II1l01;assign Il0O11=IIO11l[4:0]-5'd26;assign I10O11=IllI11;assign I00011=4928'h0;assign
II0011=1'b0;always @(I11lI1 or IIOIll or I0OI1l or I0II01)begin case (1'b1)I11lI1:I10011=IIOIll;I0OI1l:I10011=62'h0;I0II01:I10011=62'd1;default :I10011=62'h2aaaaaaaaaaaaaaa;endcase end assign IO0I11=I11lI1
|| IO1Il1|| I01101|| II1OI1|| I01OI1;always @(I11II1 or IlOIll or IIOI1l or Il0lOl or IO11I1 or II0lOl or IOII01 or I1OIO1 or IlOI1l)begin case (1'b1)I11II1:II0I11=IlOIll;IIOI1l:II0I11=Il0lOl;IO11I1:II0I11=II0lOl
;IOII01:II0I11=I1OIO1[29:0];IlOI1l:II0I11=30'h0;default :II0I11=30'b101010101010101010101010101010;endcase end assign Il0I11=I11II1|| I011I1|| I010I1|| IO11I1|| IO1OI1|| I11101|| I110l1|| IO1101;assign
IO0l11=Il1101 ? I1OIll:IIOl1l[33:4];assign I00l11=Il1101|| I11Ol1;assign Il0l11=1'b0;assign I10l11=1'b0;assign I00111=1'b0;assign II0111=1'b0;assign I10111=Il0111[8]? 9'h0:{Il0111[7:0],IOO0O1&& Il0111==
9'd0};assign IOIOO1=Il0111[8]|| IOO0O1&& Il0111== 9'd0|| Il0111[7:0]!= 8'd0&& (!Il0111[4]|| IIIII1);assign IIIOO1=5'h0;assign IlIOO1=1'b0;assign IOI0O1=!I1OI1l&& I100l1[31];assign I0I0O1=Il0111[8]&& (
I001l1|| Il0Ol1)|| Il0111[1];assign IlI0O1=1'b0;assign I1I0O1=Il0111[6]&& I101ll&& !I00O1l|| Il0111[5];assign I0IIO1=I0O11l;assign IIIIO1=IOIII1;assign I1IIO1=IIOl1l;assign IOIlO1=I0III1;assign IIIlO1
=I0O01l ? IOOlll:I10I11;assign IlIlO1=I0O01l|| Il0111[5];assign IOI1O1=IOOl1l ? I0Olll:IIOlll;assign I0I1O1=Il0111[8]&& (I001l1|| Il0Ol1|| IIOOO1)|| Il0111[7];assign I0Ol1l=(Il0011[2]&& (Il0011[3]|| Il0011
[1:0]!= 2'd0))? I1Ol1l:{1'd0,Il0011[61:3]};assign IIO11l=IO0I1l ? 32'd0:IO00Ol;assign IlO11l=(I10I11[10]&& IO0l0l&& I00l0l)? 32'd10:I1O11l;assign I1O11l=(I10I11[11]&& I00l0l)? 32'd11:((I10I11[12]&& (!I10I11
[13]|| II0I1l)&& II0l0l&& Il0l0l)? 32'd12:IO0OOl);assign IO0OOl=(I10I11[13]&& II0l0l&& Il0l0l)? 32'd13:I00OOl;assign I00OOl=(I10I11[14]&& Il0l0l)? 32'd14:((I10I11[15]&& (!I10I11[16]|| Il0I1l)&& I10l0l
&& IO010l)? 32'd15:II0OOl);assign II0OOl=(I10I11[16]&& I10l0l&& IO010l)? 32'd16:Il0OOl;assign Il0OOl=(I10I11[17]&& IO010l)? 32'd17:((I10I11[18]&& (!I10I11[19]|| I10I1l)&& I0010l&& II010l)? 32'd18:I10OOl
);assign I10OOl=(I10I11[19]&& I0010l&& II010l)? 32'd19:I000Ol;assign IO00Ol=(I10I11[1]&& I00OIl&& II0OIl)? 32'd1:I100Ol;assign I000Ol=(I10I11[20]&& II010l)? 32'd20:((I10I11[21]&& (!I10I11[22]|| IO0l1l
)&& Il010l&& I1010l)? 32'd21:II00Ol);assign II00Ol=(I10I11[22]&& Il010l&& I1010l)? 32'd22:Il00Ol;assign Il00Ol=(I10I11[23]&& I1010l)? 32'd23:((I10I11[24]&& (!I10I11[25]|| I00l1l)&& IO0OIl)? 32'd24:((I10I11
[25]&& IO0OIl)? 32'd25:((I10I11[26]&& !I10I11[27]&& !I10I11[28]&& !I10I11[29])? 32'd26:((I10I11[27]&& !I10I11[28]&& !I10I11[29])? 32'd27:((I10I11[28]&& !I10I11[29])? 32'd28:(I10I11[29]? 32'd29:32'd0))
))));assign I100Ol=(I10I11[2]&& II0OIl)? 32'd2:((I10I11[3]&& (!I10I11[4]|| II0l1l)&& Il0OIl&& I10OIl)? 32'd3:IO0IOl);assign IO0IOl=(I10I11[4]&& Il0OIl&& I10OIl)? 32'd4:I00IOl;assign I00IOl=(I10I11[5]&&
I10OIl)? 32'd5:((I10I11[6]&& (!I10I11[7]|| Il0l1l)&& IO00Il&& I000Il)? 32'd6:II0IOl);assign II0IOl=(I10I11[7]&& IO00Il&& I000Il)? 32'd7:Il0IOl;assign Il0IOl=(I10I11[8]&& I000Il)? 32'd8:((I10I11[9]&& (
!I10I11[10]|| I00I1l)&& IO0l0l&& I00l0l)? 32'd9:IlO11l);assign I00I0l=(I0IlO1[2]&& I0IlO1[1:0]== 2'b0)? I0IlO1[3]|| III0O1:I0IlO1[2]&& I0IlO1[1:0]!= 2'b0;assign II0I0l=~I100l1[31]& IO001l& II001l;assign
Il0I0l=!II0I0l&& (I100l1[31]& I0001l& II001l|| ~I100l1[31]& I0001l& II001l);assign I10I0l=I10O1l&& I10I11!= 30'd0&& !IO0IIl;assign IO0l0l=!I10I11[11]|| I10I11[12]|| I10I11[13]|| II0I1l;assign I00l0l=(
!I10I11[12]|| I10I11[13]|| II0I1l)&& (!I10I11[13]|| II0I1l)&& II0l0l&& Il0l0l;assign II0l0l=!I10I11[14]|| I10I11[15]|| I10I11[16]|| Il0I1l;assign Il0l0l=(!I10I11[15]|| I10I11[16]|| Il0I1l)&& (!I10I11[
16]|| Il0I1l)&& I10l0l&& IO010l;assign I10l0l=!I10I11[17]|| I10I11[18]|| I10I11[19]|| I10I1l;assign IO010l=(!I10I11[18]|| I10I11[19]|| I10I1l)&& (!I10I11[19]|| I10I1l)&& I0010l&& II010l;assign I0010l=
!I10I11[20]|| I10I11[21]|| I10I11[22]|| IO0l1l;assign II010l=(!I10I11[21]|| I10I11[22]|| IO0l1l)&& (!I10I11[22]|| IO0l1l)&& Il010l&& I1010l;assign Il010l=!I10I11[23]|| I10I11[24]|| I10I11[25]|| I00l1l
;assign I1010l=(!I10I11[24]|| I10I11[25]|| I00l1l)&& (!I10I11[25]|| I00l1l)&& IO0OIl;assign IO0OIl=(!I10I11[26]|| I10I11[27]|| I10I11[28]|| I10I11[29])&& !I10I11[27]&& !I10I11[28]&& !I10I11[29];assign
I00OIl=!I10I11[2]|| I10I11[3]|| I10I11[4]|| II0l1l;assign II0OIl=(!I10I11[3]|| I10I11[4]|| II0l1l)&& (!I10I11[4]|| II0l1l)&& Il0OIl&& I10OIl;assign Il0OIl=!I10I11[5]|| I10I11[6]|| I10I11[7]|| Il0l1l;assign
I10OIl=(!I10I11[6]|| I10I11[7]|| Il0l1l)&& (!I10I11[7]|| Il0l1l)&& IO00Il&& I000Il;assign IO00Il=!I10I11[8]|| I10I11[9]|| I10I11[10]|| I00I1l;assign I000Il=(!I10I11[9]|| I10I11[10]|| I00I1l)&& (!I10I11
[10]|| I00I1l)&& IO0l0l&& I00l0l;assign II00Il=I10I11!= 30'd0&& IO0IIl&& !I100Il&& I1001l;assign Il00Il=I10I11!= 30'd0&& IO0IIl&& !I100Il&& !I1001l;assign Il01Ol={Il0O0l[27],Il0O0l};assign IIOl1l={IOO11l
[58],IOO11l};assign I100Il={32'd0,I10I11}== I1OIO1;assign IO0IIl={32'd0,I10I11}<= I1OIO1;assign I00IIl=IOO1O1== 3'd2|| IOO1O1== 3'd1&& !IlO1O1;assign II0IIl=I0OO01== 3'd2|| I0OO01== 3'd1&& !I1OO01;assign
Il0IIl=IIO001== 3'd2|| IIO001== 3'd1&& !IOOI01;assign I10IIl=IlOI01== 3'd2|| IlOI01== 3'd1&& !I0Ol01;assign IO0lIl=I10IIl&& I00IIl&& II0IIl&& Il0IIl&& I001ll&& IO01ll&& I10lll;assign I00lIl=I1Ol01== 3'd2
|| I1Ol01== 3'd1&& !IIO101;assign II0lIl=IOOOI1== 3'd2|| IOOOI1== 3'd1&& !IlOOI1;assign Il0lIl=I0O0I1== 3'd2|| I0O0I1== 3'd1&& !I1O0I1;assign I10lIl=Il0lIl&& I00lIl&& II0lIl&& Il0IIl&& II0IIl&& I00IIl
&& I10IIl;assign IO01Il=IIOII1== 3'd2|| IIOII1== 3'd1&& !IOOlI1;assign I001Il=IlOlI1== 3'd2|| IlOlI1== 3'd3|| IlOlI1== 3'd1&& !I0O1I1;assign II01Il=I1O1I1== 3'd2|| I1O1I1== 3'd1&& !IIOOl1;assign Il01Il
=IOO0l1== 3'd2|| IOO0l1== 3'd1&& !IlO0l1;assign I101Il=Il01Il&& IO01Il&& I001Il&& II01Il&& II0lIl&& I00lIl&& Il0lIl;assign IO0Oll=I0OIl1== 3'd2|| I0OIl1== 3'd1&& !I1OIl1;assign I00Oll=II0Oll&& Il0Oll&&
I10Oll&& I000ll&& I100ll&& IO0Ill&& II0Ill;assign II0Oll=IIOll1== 3'd2|| IIOll1== 3'd1&& !IOO1l1;assign Il0Oll=IlO1l1== 3'd2|| IlO1l1== 3'd1&& !I0OO11;assign I10Oll=I1OO11== 3'd2|| I1OO11== 3'd1&& !IIO011
;assign IO00ll=I000ll&& I100ll&& IO0Ill&& II0Ill&& II0lIl&& I00lIl&& Il0lIl;assign I000ll=IOOI11== 3'd2|| IOOI11== 3'd1&& !IlOI11;assign II00ll=I000ll&& I100ll&& IO0Ill&& II0Ill&& I001ll&& IO01ll&& I10lll
;assign Il00ll=I100ll&& IO0Ill&& II0Ill&& II01Il&& I001Il&& IO01Il&& Il01Il;assign I100ll=I0Ol11== 3'd2|| I0Ol11== 3'd1&& !I1Ol11;assign IO0Ill=IIO111== 3'd2|| IIO111== 3'd1&& !IO0OO1;assign I00Ill=IO0Ill
&& I100ll&& I000ll&& I10Oll&& Il0Oll&& II0Oll&& IO0Oll&& I10Ill;assign II0Ill=Il0OO1== 3'd2|| Il0OO1== 3'd1&& !I000O1;assign Il0Ill=I10Ill&& IO0Oll&& II0Oll&& Il0Oll&& I10Oll&& I000ll&& Il00ll;assign I10Ill
=I100O1== 3'd2|| I100O1== 3'd1&& !II0IO1;assign IO0lll=IO0lO1== 3'd2|| IO0lO1== 3'd1&& !Il0lO1;assign I00lll=I001O1== 3'd2|| I001O1== 3'd1&& !I101O1;assign II0lll=II0O01== 3'd2|| II0O01== 3'd1&& !IO0001
;assign Il0lll=Il0001== 3'd2|| Il0001== 3'd1&& !I00I01;assign I10lll=Il0lll&& II0lll&& I00lll&& IO0lll&& II01ll;assign IO01ll=I10I01== 3'd2|| I10I01== 3'd1&& !II0l01;assign I001ll=IO0101== 3'd2|| IO0101
== 3'd1&& !Il0101;assign II01ll=I00OI1== 3'd2|| I00OI1== 3'd1&& !I10OI1;assign Il01ll=II01ll&& IO0lll&& I00lll&& II0lll&& Il0lll&& IO01ll&& I001ll;assign IO000l=I00lI1+9'd127;assign I101ll=(I0000l^ 9'h100
)<= 9'd128;assign IO0O1l=(I0000l^ 9'h100)<= 9'd382;assign I00O1l=(I0000l^ 9'h100)<9'd105;assign I0000l=I00lI1+{{4{II0O11[4]}},II0O11};assign Il0O0l=I101Ol[28:1];assign I101Ol=I10lI1+29'd67108864;assign
I10IOl={I00O0l[28],I00O0l};assign II0O1l=IO0Ol1<I101l1;assign Il0O1l=I10O1l&& I10I11!= 30'd0&& IO0IIl&& I100Il;assign I10O1l=I000l1<8'd7;assign IO001l=I100l1[30:23]== 8'hff;assign I0001l=I100l1[30:23]
== 8'h0;assign II000l={II0Il1[7],II0Il1}+9'd1;assign II001l=I100l1[22:0]== 23'b0;assign Il001l=IO001l& ~II001l| I100l1[31]& ~II001l| I100l1[31]& I10l1l;assign IO0O0l={2'b0,Il0ll1,3'b0};assign I1001l=I00I11
<I10I11;assign IO0I1l=I10I11[0]&& (!I10I11[1]|| I10I11[2]|| I10I11[3]|| I10I11[4]|| II0l1l)&& I00OIl&& II0OIl;assign I00I1l=I10I11[11]|| I10I11[12]|| I10I11[13]|| II0I1l;assign II0I1l=I10I11[14]|| I10I11
[15]|| I10I11[16]|| Il0I1l;assign Il0I1l=I10I11[17]|| I10I11[18]|| I10I11[19]|| I10I1l;assign I10I1l=I10I11[20]|| I10I11[21]|| I10I11[22]|| IO0l1l;assign IO0l1l=I10I11[23]|| I10I11[24]|| I10I11[25]|| I00l1l
;assign I00l1l=I10I11[26]|| I10I11[27]|| I10I11[28]|| I10I11[29];assign II0l1l=I10I11[5]|| I10I11[6]|| I10I11[7]|| Il0l1l;assign Il0l1l=I10I11[8]|| I10I11[9]|| I10I11[10]|| I00I1l;assign IO0I0l=I10I11
[29:26];assign IO0lOl={I10I11[25:0],4'd0};assign IlOl1l={I00lOl,IO0lOl}+{I10IOl,I0O11l[29:0]};assign IOO11l=IlOl1l[59:1];assign I00lOl={{26{IO0I0l[3]}},IO0I0l};assign I1Ol1l={1'd0,Il0011[61:3]}+60'd1;
assign II0lOl=Il0lOl-I10I11;assign I00O0l=I0O11l[58:30];assign Il0lOl={I00I11[28:0],I1OIO1[61]};assign I0O11l=I0Ol1l[59]? 59'h7ffffffffffffff:I0Ol1l[58:0];assign I10lOl=I0IlO1>> Il000l;assign Il000l=IO000l
[8]? -IO000l:IO000l;assign IO01Ol=I0IlO1<< Il000l;assign I001Ol=I0IlO1>> I1000l;assign II01Ol=I0IlO1<< I1000l;assign I1000l=II0O11[4]? -II0O11:II0O11;assign I10O0l={I0IlO1[25:3]+23'd1,I0IlO1[2:0]};assign
I10l1l=~I0001l;assign II0O0l={1'd0,Il0ll1,4'b0};always @(posedge CLK)begin if(!nRST)begin IIOOO1<= 1'b0;IOO0O1<= 1'b0;IlO0O1<= 62'h0;I0OIO1<= 1'd0;I1OIO1<= 62'h0;IIOlO1<= 62'h0;IOO1O1<= 3'd1;IlO1O1<= 1'd0
;I0OO01<= 3'd1;I1OO01<= 1'd0;IIO001<= 3'd1;IOOI01<= 1'd0;IlOI01<= 3'd1;I0Ol01<= 1'd0;I1Ol01<= 3'd1;IIO101<= 1'd0;IOOOI1<= 3'd1;IlOOI1<= 1'd0;I0O0I1<= 3'd1;I1O0I1<= 1'd0;IIOII1<= 3'd1;IOOlI1<= 1'd0;IlOlI1
<= 3'd1;I0O1I1<= 1'd0;I1O1I1<= 3'd1;IIOOl1<= 1'd0;IOO0l1<= 3'd1;IlO0l1<= 1'd0;I0OIl1<= 3'd1;I1OIl1<= 1'd0;IIOll1<= 3'd1;IOO1l1<= 1'd0;IlO1l1<= 3'd1;I0OO11<= 1'd0;I1OO11<= 3'd1;IIO011<= 1'd0;IOOI11<= 3'd1
;IlOI11<= 1'd0;I0Ol11<= 3'd1;I1Ol11<= 1'd0;IIO111<= 3'd1;IO0OO1<= 1'd0;Il0OO1<= 3'd1;I000O1<= 1'd0;I100O1<= 3'd1;II0IO1<= 1'd0;IO0lO1<= 3'd1;Il0lO1<= 1'd0;I001O1<= 3'd1;I101O1<= 1'd0;II0O01<= 3'd1;IO0001
<= 1'd0;Il0001<= 3'd1;I00I01<= 1'd0;I10I01<= 3'd1;II0l01<= 1'd0;IO0101<= 3'd1;Il0101<= 1'd0;I00OI1<= 3'd1;I10OI1<= 1'd0;II00I1<= 1'd0;IO0II1<= 4'd1;Il0II1<= 1'd0;I00lI1<= 9'h0;I10lI1<= 29'h0;II01I1<= 154'd0
;IO0Ol1<= 8'h0;Il0Ol1<= 1'b0;I000l1<= 8'h0;I100l1<= 32'd0;II0Il1<= 8'h0;IO0ll1<= 1'd0;Il0ll1<= 24'h0;I001l1<= 1'b0;I101l1<= 8'h0;II0O11<= 5'h0;IO0011<= 4928'd0;Il0011<= 62'h0;I00I11<= 30'h0;I10I11<= 30'h0
;II0l11<= 1'd0;IO0111<= 1'd0;Il0111<= 9'd0;I0IOO1<= 5'h0;I1IOO1<= 1'd0;III0O1<= 1'd0;IOIIO1<= 59'h0;IlIIO1<= 60'h0;I0IlO1<= 30'h0;I1IlO1<= 26'h0;end else begin if(I1OOO1)IIOOO1<= IlOOO1;if(IIO0O1)IOO0O1
<= I0O0O1;if(IOOIO1)IlO0O1<= I1O0O1;if(IlOIO1)I0OIO1<= IIOIO1;if(I0OlO1)I1OIO1<= IOOlO1;if(I1OlO1)IIOlO1<= IlOlO1;if(IIO1O1)IOO1O1<= I0O1O1;if(IOOO01)IlO1O1<= I1O1O1;if(IlOO01)I0OO01<= IIOO01;if(I0O001
)I1OO01<= IOO001;if(I1O001)IIO001<= IlO001;if(IIOI01)IOOI01<= I0OI01;if(IOOl01)IlOI01<= I1OI01;if(IlOl01)I0Ol01<= IIOl01;if(I0O101)I1Ol01<= IOO101;if(I1O101)IIO101<= IlO101;if(IIOOI1)IOOOI1<= I0OOI1;if
(IOO0I1)IlOOI1<= I1OOI1;if(IlO0I1)I0O0I1<= IIO0I1;if(I0OII1)I1O0I1<= IOOII1;if(I1OII1)IIOII1<= IlOII1;if(IIOlI1)IOOlI1<= I0OlI1;if(IOO1I1)IlOlI1<= I1OlI1;if(IlO1I1)I0O1I1<= IIO1I1;if(I0OOl1)I1O1I1<= IOOOl1
;if(I1OOl1)IIOOl1<= IlOOl1;if(IIO0l1)IOO0l1<= I0O0l1;if(IOOIl1)IlO0l1<= I1O0l1;if(IlOIl1)I0OIl1<= IIOIl1;if(I0Oll1)I1OIl1<= IOOll1;if(I1Oll1)IIOll1<= IlOll1;if(IIO1l1)IOO1l1<= I0O1l1;if(IOOO11)IlO1l1<=
I1O1l1;if(IlOO11)I0OO11<= IIOO11;if(I0O011)I1OO11<= IOO011;if(I1O011)IIO011<= IlO011;if(IIOI11)IOOI11<= I0OI11;if(IOOl11)IlOI11<= I1OI11;if(IlOl11)I0Ol11<= IIOl11;if(I0O111)I1Ol11<= IOO111;if(I1O111)IIO111
<= IlO111;if(II0OO1)IO0OO1<= I00OO1;if(IO00O1)Il0OO1<= I10OO1;if(Il00O1)I000O1<= II00O1;if(I00IO1)I100O1<= IO0IO1;if(I10IO1)II0IO1<= Il0IO1;if(II0lO1)IO0lO1<= I00lO1;if(IO01O1)Il0lO1<= I10lO1;if(Il01O1
)I001O1<= II01O1;if(I00O01)I101O1<= IO0O01;if(I10O01)II0O01<= Il0O01;if(II0001)IO0001<= I00001;if(IO0I01)Il0001<= I10001;if(Il0I01)I00I01<= II0I01;if(I00l01)I10I01<= IO0l01;if(I10l01)II0l01<= Il0l01;if
(II0101)IO0101<= I00101;if(IO0OI1)Il0101<= I10101;if(Il0OI1)I00OI1<= II0OI1;if(I000I1)I10OI1<= IO00I1;if(I100I1)II00I1<= Il00I1;if(II0II1)IO0II1<= I00II1;if(IO0lI1)Il0II1<= I10II1;if(Il0lI1)I00lI1<= II0lI1
;if(I001I1)I10lI1<= IO01I1;if(I101I1)II01I1<= Il01I1;if(II0Ol1)IO0Ol1<= I00Ol1;if(IO00l1)Il0Ol1<= I10Ol1;if(Il00l1)I000l1<= II00l1;if(I00Il1)I100l1<= IO0Il1;if(I10Il1)II0Il1<= Il0Il1;if(II0ll1)IO0ll1<=
I00ll1;if(IO01l1)Il0ll1<= I10ll1;if(Il01l1)I001l1<= II01l1;if(I00O11)I101l1<= IO0O11;if(I10O11)II0O11<= Il0O11;if(II0011)IO0011<= I00011;if(IO0I11)Il0011<= I10011;if(Il0I11)I00I11<= II0I11;if(I00l11)I10I11
<= IO0l11;if(I10l11)II0l11<= Il0l11;if(II0111)IO0111<= I00111;if(IOIOO1)Il0111<= I10111;if(IlIOO1)I0IOO1<= IIIOO1;if(I0I0O1)I1IOO1<= IOI0O1;if(I1I0O1)III0O1<= IlI0O1;if(IIIIO1)IOIIO1<= I0IIO1;if(IOIlO1
)IlIIO1<= I1IIO1;if(IlIlO1)I0IlO1<= IIIlO1;if(I0I1O1)I1IlO1<= IOI1O1;end end endmodule
